(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    171970,       5713]
NotebookOptionsPosition[    147209,       5020]
NotebookOutlinePosition[    148508,       5060]
CellTagsIndexPosition[    148415,       5054]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Lie Algebras", "Title",
 TextAlignment->Center],

Cell["by", "Subsubtitle",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 TextAlignment->Center,
 FontFamily->"Times New Roman",
 FontSize->14,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell["Rolf Sulanke", "Subtitle",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 CellChangeTimes->{{3.471757873260313*^9, 3.471757874837994*^9}, 
   3.471769839625605*^9},
 TextAlignment->Center],

Cell["\<\
November 20, 1999
Revised January 7, 2010\
\>", "Subsubtitle",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 CellChangeTimes->{{3.471964957231983*^9, 3.471964977313934*^9}},
 TextAlignment->Center],

Cell["Summary", "Subsubtitle",
 TextAlignment->Center],

Cell[TextData[{
 "In this notebook we define basic operations for Lie algebras and calculate \
the Killing forms of the following Lie algebras:\nthe general linear Lie \
algebras gl(n,K),\nthe special linear  Lie algebras sl(n,K),\nthe orthogonal \
Lie algebras o(n), \nthe pseudo-orthogonal Lie algebras o(n, l),\nthe \
symplectic Lie algebras sp(2n, K),\nthe unitary Lie algebras u(n),\nthe \
special unitary Lie algebras su(n).\nHere K denotes the fields of the real or \
the complex numbers. Other real forms or complex Lie algebras can be treated \
similarly; we leave the details to the interested user. Furthermore we \
construct an orthonormalization procedure appropriate for arbitrary symmetric \
 bilinear forms defined on spaces of matrices, in particular for Killing \
forms.  By the help of this  orthonormalization we calculate the index of the \
considered  Killing forms (in the real case),  and compare it with the index  \
listed in [",
 ButtonBox["3",
  BaseStyle->"Hyperlink",
  ButtonData->"ref"],
 "]. It is well known that the Killing forms play an important role in the \
classification of semisimple Lie algebras and the geometric applications of \
semisimple Lie groups, see e.g. the book S. HELGASON [",
 ButtonBox["1",
  BaseStyle->"Hyperlink",
  ButtonData->"ref"],
 "]. Applications for finding geodesics in the M\[ODoubleDot]bius geometry of \
spaces of m-spheres are contained in [",
 ButtonBox["2",
  BaseStyle->"Hyperlink",
  ButtonData->"ref"],
 "]. In principle the tools developed in this notebook give the possibility \
to perform any  calculation in the series of Lie algebras listed above."
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.471616297779684*^9, 3.471616297780933*^9}, {
  3.471616364883134*^9, 3.471616385098485*^9}}],

Cell[CellGroupData[{

Cell["Keywords ", "Subsubsection"],

Cell["\<\
indefinite scalar products, Lie algebra, semisimple Lie algebra, compact Lie \
algebra, orthogonal Lie algebra, pseudo-orthogonal Lie algebra, linear Lie \
algebra, special linear Lie algebra, symplectic Lie algebra, unitary Lie \
algebra, special unitary Lie algebra, orthogonalization, Killing form, \
commutator, Jacoby identity, structure constants, center.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1 Introduction, Initialization", "Section"],

Cell[CellGroupData[{

Cell["1.1 The Killing form ", "Subsection"],

Cell[TextData[{
 "The ",
 StyleBox["Killing form",
  FontColor->RGBColor[0, 0, 1]],
 " is a symmetric bilinear form on the Lie algebra defined as the trace of \
the linear endomorphism"
}], "Text"],

Cell["\<\
tr[a,b] :=  trace[ad[a]\[SmallCircle]ad[b]],\
\>", "Text",
 TextAlignment->Center],

Cell["where", "Text"],

Cell["\<\
a \[RightTeeArrow] ad[a],\tad[a][x] := commute[a, x],\
\>", "Text",
 TextAlignment->Center],

Cell[TextData[{
 "denotes the ",
 StyleBox["adjoint representation",
  FontColor->RGBColor[0, 0, 1]],
 " of the Lie algebra. In general, the Killing form is neither definite nor \
non degenerate.  By E. Cartan's criterion the Lie algebra is ",
 StyleBox["semisimple",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 "if and only if its Killing form is non degenerate; a semisimple Lie algebra \
is ",
 StyleBox["compact",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 "(that means, the corresponding connected Lie groups are compact) if and \
only if its Killing form is (negative) definite. The semisimple Lie algebras \
may be decomposed into a direct sum of simple Lie algebras, which are \
classified, see [",
 ButtonBox["1",
  BaseStyle->"Hyperlink",
  ButtonData->"ref"],
 "],  [3]. In the summary we indicated the main types of  infinite series of ",
 StyleBox["simple",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontColor->RGBColor[1, 0, 0]],
 "Lie algebras: sl(n,K), o(n) (n\[NotEqual]2,4), sp(2n,K); besides of these \
there exist yet a finite number of so called exceptional simple Lie algebras, \
which we shall not consider in this notebook. The Lie algebras o(n, l) (n\
\[NotEqual]2,4), su(n) are real simple Lie algebras; besides of them there \
exists yet other simple real Lie algebras not considered here. The Lie \
algebras gl(n,K), u(n) are not simple; they are direct products of their \
one-dimensional center and the simple Lie algebras sl(n.K) resp. su(n).   \
Below we consider the  Lie algebras over the complex or the real numbers \
mentioned in the summary, and calculate their Killing forms.  "
}], "Text",
 CellChangeTimes->{{3.471616486156408*^9, 3.471616486157502*^9}, {
  3.471616517383745*^9, 3.47161651817148*^9}, {3.47161658161282*^9, 
  3.471616584033106*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2 Initialization", "Subsection"],

Cell[TextData[StyleBox["Activite Kernel/Evaluation/Evaluate/Initialization \
from the menu!",
 FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[TextData[{
 "The concepts considered in this notebook depend on  the dimension dim of \
the underlying vector space (= the order of the square matrices) and, in the \
pseudo-euclidean case,  the index  ind of the (non-degenerate, symmetric) \
scalar product on this space. These basic constants should be  defined after \
the initialization; then their values with 0\[LessEqual]ind\[LessEqual]dim \
may be  changed later.  If fixed before the initialization, these constants \
could not be changed later for initialized  functions in which they appear. \
",
 StyleBox["Thus the initialization cells should not be evaluated if dim and \
ind have defined values already.",
  FontColor->RGBColor[1, 0, 0]]
}], "Text",
 CellChangeTimes->{{3.471616648486045*^9, 3.47161666229655*^9}, {
  3.471616726805984*^9, 3.471616728356567*^9}, {3.471616759954319*^9, 
  3.471616794932702*^9}, {3.471616869781403*^9, 3.471617049738197*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", " ", 
  RowBox[{"ind", " ", "=", " ", "1"}], ";"}]], "Input",
 CellChangeTimes->{3.471617144689209*^9},
 CellLabel->"In[47]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3 The packages liealg.m, liealgun.m", "Subsection",
 CellChangeTimes->{3.471617295429117*^9}],

Cell[TextData[{
 "Almost all the modules contained in initialization cells of this notebook \
are collected, and provided with usages, in the packages liealg.m and  \
liealgun.m. The latter contains the concepts concerning the unitary Lie \
algebras. It needs, besides of liealg.m, the package [",
 ButtonBox["4",
  BaseStyle->"Hyperlink",
  ButtonData->"ref"],
 "] of Pekka Janhunen, which may be downloaded from ",
 ButtonBox["my homepagee",
  BaseStyle->"Hyperlink",
  ButtonData->"home"],
 StyleBox[". ",
  FontSlant->"Italic"],
 StyleBox["This package is also needed for evaluating section 6 of the \
notebook. Sections 1 - 5 do not need any import of packages; the packages \
liealg.m liealgun.m are prepared for arbitrary applications, as enhancements \
of ",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["Mathematica",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[". \n",
  FontSlant->"Italic"],
 StyleBox["WARNING",
  FontVariations->{"CompatibilityType"->0},
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[": It is not recommended, and not necessary, to import the packages \
liealg.m, liealgun.m  in this notebook! The symbols in these packages are \
protected, therefore you will get error messages if you evaluate the \
corresponding defining cells of the notebook after the import of the \
packages.",
  FontVariations->{"CompatibilityType"->0}]
}], "Text",
 CellChangeTimes->{{3.47161732018898*^9, 3.471617364955808*^9}, {
  3.471617401716529*^9, 3.471617407322638*^9}, {3.471617514781902*^9, 
  3.471617514785192*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["1.4 Some tools", "Subsection",
 CellChangeTimes->{3.471617289599267*^9}],

Cell[CellGroupData[{

Cell["A general vector, random vectors, random matrices", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", 
   RowBox[{"x_", ",", " ", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"x", "[", "i", "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "n"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[1]:="],

Cell[BoxData[
 RowBox[{"vec", "[", "Sin", "]"}]], "Input",
 CellLabel->"In[48]:="],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomv", "[", 
   RowBox[{"n_", ":", "dim"}], "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"RandomReal", "[", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[2]:="],

Cell[BoxData[
 RowBox[{"randomv", "[", "]"}]], "Input",
 CellLabel->"In[50]:="],

Cell[BoxData[
 RowBox[{"randomv", "[", "5", "]"}]], "Input",
 CellChangeTimes->{3.471617709684992*^9},
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{"randomv", "[", "0", "]"}]], "Input",
 CellLabel->"In[53]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"randommatrix", "[", 
    RowBox[{"k_", ",", " ", 
     RowBox[{"n_:", "dim"}]}], "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"randomv", "[", "n", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "k"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"randommatrix", "[", "]"}], ":=", " ", 
  RowBox[{"randommatrix", "[", 
   RowBox[{"dim", ",", "dim"}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.471617852533078*^9, 3.471617853798819*^9}, {
  3.471617884596133*^9, 3.471617907254981*^9}},
 CellLabel->"In[3]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"randommatrix", "[", 
   RowBox[{"2", ",", "4"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.471617781728948*^9, 3.471617790027897*^9}},
 CellLabel->"In[63]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"randommatrix", "[", "4", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[64]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"randommatrix", "[", "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.471617815988333*^9, 3.471617824261179*^9}},
 CellLabel->"In[65]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Smoothing", "Subsubsection"],

Cell[TextData[{
 "The following function makes an almost zero  number to be zero; the \
sensibility can be regulated by the optional second argument, whose default \
value is ",
 Cell[BoxData[
  SuperscriptBox["10", 
   RowBox[{"-", "10"}]]]],
 ":"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"smoothing", "[", 
    RowBox[{"a_", ",", 
     RowBox[{"b_:", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{"-", "10"}], ")"}]}]}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", "=", "a"}], "}"}], ",", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"b", "\[Equal]", "1"}], ",", 
       RowBox[{"Return", "[", "c", "]"}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"N", "[", "c", "]"}], "]"}], "<", "b"}], ",", 
          RowBox[{"c", "=", "0"}]}], "]"}], ";", " ", "c"}], ",", "c"}], 
      "]"}]}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"Attributes", "[", "smoothing", "]"}], "=", "Listable"}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[5]:="],

Cell[BoxData[
 RowBox[{"?", "Chop"}]], "Input",
 CellChangeTimes->{{3.471618144126159*^9, 3.471618146112195*^9}},
 CellLabel->"In[66]:="],

Cell[TextData[{
 "For the relations between Chop and smoothing see the notebook Chop.nb on my \
",
 ButtonBox["homepage",
  BaseStyle->"Hyperlink",
  ButtonData->"home"],
 "."
}], "Text",
 CellChangeTimes->{{3.47161817440127*^9, 3.471618239083006*^9}, {
  3.471618289788564*^9, 3.471618289789655*^9}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2 The general and the special linear Lie algebras", "Section"],

Cell[CellGroupData[{

Cell["2.1 Basic definitions", "Subsection"],

Cell[TextData[{
 "In ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " the addition and the multiplication of matrices are implemented linear \
operations. We combine them in the definition of the commutator, which is the \
basic operation for Lie algebras. We test the properties of some combinations \
of these operations in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " and apply them to define basic concepts for the general linear Lie algebra \
gl(n, K), which is defined as the vector space of all square matrices of \
order n over the field K, provided with the commutator operation. "
}], "Text",
 CellChangeTimes->{{3.471618376681068*^9, 3.47161838272515*^9}}],

Cell[CellGroupData[{

Cell["Symbolic matrices and commutator", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"nullmatrix", "[", 
    RowBox[{"k_", ",", " ", 
     RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", " ", 
     RowBox[{"{", "k", "}"}], ",", " ", 
     RowBox[{"{", "n", "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"nullmatrix", "[", "n_", "]"}], " ", ":=", " ", 
   RowBox[{"nullmatrix", "[", 
    RowBox[{"n", ",", " ", "n"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"nullmatrix", "[", "]"}], " ", ":=", " ", 
  RowBox[{"nullmatrix", "[", "dim", "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.471618455758705*^9, 3.471618457739714*^9}, 
   3.471618622735594*^9, 3.471618691772435*^9, 3.471618731301563*^9, {
   3.471672553119004*^9, 3.471672553629325*^9}, 3.47167273437204*^9, 
   3.471672828469202*^9},
 CellLabel->"In[6]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"nullmatrix", "[", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[59]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"nullmatrix", "[", 
   RowBox[{"3", ",", "5"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[87]:="],

Cell["\<\
We want to distinguish vector Arrays from matrix Arrays, and to have a simple \
construction of square matrices with given dimension. Therefore we define:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"matrix", "[", 
    RowBox[{"a_", ",", "n_", ",", "m_"}], "]"}], ":=", " ", 
   RowBox[{"Array", "[", 
    RowBox[{"a", ",", " ", 
     RowBox[{"{", 
      RowBox[{"n", ",", " ", "m"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"matrix", "[", 
   RowBox[{"a_", ",", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"matrix", "[", 
   RowBox[{"a", ",", " ", "n", ",", " ", "n"}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[9]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrix", "[", "a", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[60]:="],

Cell["\<\
The commutator is the basic operation in Lie algebra; for Lie algebras of \
matrices the commutator is defined as follows:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"commute", "[", 
   RowBox[{"m_", ",", " ", "l_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"m", " ", ".", " ", "l"}], " ", "-", " ", 
    RowBox[{"l", " ", ".", " ", "m"}]}], "]"}], " "}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.471618899029179*^9, 3.471618941924541*^9}},
 CellLabel->"In[11]:="],

Cell[TextData[{
 "The following true equation is the ",
 StyleBox["Jacoby identity",
  FontColor->RGBColor[0, 0, 1]],
 ":"
}], "Text"],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"commute", "[", 
      RowBox[{
       RowBox[{"commute", "[", 
        RowBox[{
         RowBox[{"matrix", "[", "a", "]"}], ",", " ", 
         RowBox[{"matrix", "[", "b", "]"}]}], "]"}], " ", ",", 
       RowBox[{"matrix", "[", "c", "]"}]}], "]"}], " ", "+", " ", 
     RowBox[{"commute", "[", 
      RowBox[{
       RowBox[{"commute", "[", 
        RowBox[{
         RowBox[{"matrix", "[", "b", "]"}], ",", " ", 
         RowBox[{"matrix", "[", "c", "]"}]}], "]"}], " ", ",", 
       RowBox[{"matrix", "[", "a", "]"}]}], "]"}], " ", "+", " ", 
     RowBox[{"commute", "[", 
      RowBox[{
       RowBox[{"commute", "[", 
        RowBox[{
         RowBox[{"matrix", "[", "c", "]"}], ",", " ", 
         RowBox[{"matrix", "[", "a", "]"}]}], "]"}], " ", ",", 
       RowBox[{"matrix", "[", "b", "]"}]}], "]"}]}], "]"}], "==", " ", 
   RowBox[{"nullmatrix", "[", "]"}]}], "]"}]], "Input",
 CellLabel->"In[61]:="],

Cell[TextData[{
 StyleBox["ATTENTION! ",
  FontColor->RGBColor[1, 0, 0]],
 "Without Simplify TrueQ gives False:"
}], "Text"],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"commute", "[", 
     RowBox[{
      RowBox[{"commute", "[", 
       RowBox[{
        RowBox[{"matrix", "[", "a", "]"}], ",", " ", 
        RowBox[{"matrix", "[", "b", "]"}]}], "]"}], " ", ",", 
      RowBox[{"matrix", "[", "c", "]"}]}], "]"}], " ", "+", " ", 
    RowBox[{"commute", "[", 
     RowBox[{
      RowBox[{"commute", "[", 
       RowBox[{
        RowBox[{"matrix", "[", "b", "]"}], ",", " ", 
        RowBox[{"matrix", "[", "c", "]"}]}], "]"}], " ", ",", 
      RowBox[{"matrix", "[", "a", "]"}]}], "]"}], " ", "+", " ", 
    RowBox[{"commute", "[", 
     RowBox[{
      RowBox[{"commute", "[", 
       RowBox[{
        RowBox[{"matrix", "[", "c", "]"}], ",", " ", 
        RowBox[{"matrix", "[", "a", "]"}]}], "]"}], " ", ",", 
      RowBox[{"matrix", "[", "b", "]"}]}], "]"}]}], "==", " ", 
   RowBox[{"nullmatrix", "[", "]"}]}], "]"}]], "Input",
 CellLabel->"In[62]:="],

Cell["The following would produce  a very long expression:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"commute", "[", 
    RowBox[{
     RowBox[{"commute", "[", 
      RowBox[{
       RowBox[{"matrix", "[", "a", "]"}], ",", " ", 
       RowBox[{"matrix", "[", "b", "]"}]}], "]"}], " ", ",", 
     RowBox[{"matrix", "[", "c", "]"}]}], "]"}], " ", "+", " ", 
   RowBox[{"commute", "[", 
    RowBox[{
     RowBox[{"commute", "[", 
      RowBox[{
       RowBox[{"matrix", "[", "b", "]"}], ",", " ", 
       RowBox[{"matrix", "[", "c", "]"}]}], "]"}], " ", ",", 
     RowBox[{"matrix", "[", "a", "]"}]}], "]"}], " ", "+", " ", 
   RowBox[{"commute", "[", 
    RowBox[{
     RowBox[{"commute", "[", 
      RowBox[{
       RowBox[{"matrix", "[", "c", "]"}], ",", " ", 
       RowBox[{"matrix", "[", "a", "]"}]}], "]"}], " ", ",", 
     RowBox[{"matrix", "[", "b", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.471619671125331*^9, 3.471619701326631*^9},
 CellLabel->"In[63]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellLabel->"In[120]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"commute", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"matrix", "[", "a", "]"}], " ", "+", " ", 
     RowBox[{"matrix", "[", "b", "]"}]}], ",", " ", 
    RowBox[{"matrix", "[", "b", "]"}]}], "]"}], "//", "MatrixForm"}]], "Input",\

 CellLabel->"In[124]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellLabel->"In[125]:="],

Cell[BoxData[
 RowBox[{"%", " ", "-", " ", 
  RowBox[{"commute", "[", 
   RowBox[{
    RowBox[{"matrix", "[", "a", "]"}], ",", " ", 
    RowBox[{"matrix", "[", "b", "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[127]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellLabel->"In[128]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Tests, properties", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrix", "[", "a", "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.47167746621883*^9, 3.471677477712757*^9}},
 CellLabel->"In[154]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrix", "[", "a", "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"i", ",", "j"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471676833891686*^9, 3.471676843475352*^9}},
 CellLabel->"In[145]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrix", "[", "a", "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "j"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471676833891686*^9, 3.471676843475352*^9}, {
  3.471676911494919*^9, 3.471676917991162*^9}},
 CellLabel->"In[146]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrix", "[", "a", "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471676833891686*^9, 3.471676843475352*^9}, {
  3.471676911494919*^9, 3.471676933202892*^9}},
 CellLabel->"In[147]:="],

Cell[TextData[{
 StyleBox["ATTENTION! ",
  FontColor->RGBColor[1, 0, 0]],
 "Use MatrixForm for the presentation only! \nThe result of MatrixForm is not \
a matrix!"
}], "Text",
 CellChangeTimes->{3.471619010762352*^9}],

Cell[BoxData[
 RowBox[{"mab", " ", "=", " ", 
  RowBox[{
   RowBox[{"matrix", "[", 
    RowBox[{"ab", ",", " ", "3", ",", "5"}], "]"}], "//", 
   "MatrixForm"}]}]], "Input",
 CellLabel->"In[90]:="],

Cell[BoxData[
 RowBox[{"m2ab", " ", "=", " ", 
  RowBox[{"matrix", "[", 
   RowBox[{"ab", ",", " ", "3", ",", "5"}], "]"}]}]], "Input",
 CellLabel->"In[91]:="],

Cell[BoxData[
 RowBox[{"MatrixQ", "[", "mab", "]"}]], "Input",
 CellLabel->"In[92]:="],

Cell[BoxData[
 RowBox[{"VectorQ", "[", "mab", "]"}]], "Input",
 CellLabel->"In[93]:="],

Cell[BoxData[
 RowBox[{"MatrixQ", "[", "m2ab", "]"}]], "Input",
 CellLabel->"In[94]:="],

Cell[BoxData[
 RowBox[{"VectorQ", "[", "m2ab", "]"}]], "Input",
 CellLabel->"In[95]:="],

Cell[BoxData[
 RowBox[{"Length", "[", "mab", "]"}]], "Input",
 CellLabel->"In[96]:="],

Cell[BoxData[
 RowBox[{"Length", "[", "m2ab", "]"}]], "Input",
 CellLabel->"In[97]:="],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "mab", "]"}]], "Input",
 CellLabel->"In[98]:="],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "m2ab", "]"}]], "Input",
 CellLabel->"In[99]:="],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"matrix", "[", "a", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}], "==", " ", 
   RowBox[{"a", "[", 
    RowBox[{"1", ",", "2"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[100]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"matrix", "[", "b", "]"}], ".", 
   RowBox[{"IdentityMatrix", "[", "3", "]"}]}], "//", "MatrixForm"}]], "Input",\

 CellChangeTimes->{{3.47161909652734*^9, 3.471619098983121*^9}},
 CellLabel->"In[101]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Transpose", "[", 
   RowBox[{"matrix", "[", "b", "]"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[102]:="],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"commute", "[", 
     RowBox[{
      RowBox[{"matrix", "[", "a", "]"}], ",", " ", 
      RowBox[{"matrix", "[", "b", "]"}]}], "]"}], " ", "+", " ", 
    RowBox[{"commute", "[", 
     RowBox[{
      RowBox[{"matrix", "[", "b", "]"}], ",", " ", 
      RowBox[{"matrix", "[", "a", "]"}]}], "]"}]}], "==", " ", 
   RowBox[{"nullmatrix", "[", "]"}]}], "]"}]], "Input",
 CellLabel->"In[103]:="],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   RowBox[{"commute", "[", 
    RowBox[{
     RowBox[{"matrix", "[", "a", "]"}], ",", " ", 
     RowBox[{"matrix", "[", "a", "]"}]}], " ", "]"}], "==", " ", 
   RowBox[{"nullmatrix", "[", "]"}]}], "]"}]], "Input",
 CellLabel->"In[104]:="],

Cell["\<\
The following is not a contradiction: randommatrix will always be new \
generated if it is called!\
\>", "Text"],

Cell[BoxData[
 RowBox[{"commute", "[", 
  RowBox[{
   RowBox[{"randommatrix", "[", "]"}], ",", 
   RowBox[{"randommatrix", "[", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.471619183352437*^9, 3.471619190785506*^9}},
 CellLabel->"In[106]:="],

Cell["Of course, we have", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ra", " ", "=", " ", 
   RowBox[{"randommatrix", "[", "]"}]}], ";", " ", 
  RowBox[{"commute", "[", 
   RowBox[{"ra", ",", "ra"}], "]"}]}]], "Input",
 CellChangeTimes->{3.471619204369865*^9},
 CellLabel->"In[107]:="],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   RowBox[{"randommatrix", "[", "]"}], " ", "\[Equal]", " ", 
   RowBox[{"randommatrix", "[", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.471619222520748*^9, 3.471619232685441*^9}},
 CellLabel->"In[108]:="],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   RowBox[{"randommatrix", "[", "]"}], "===", " ", 
   RowBox[{"randommatrix", "[", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.471619245230137*^9, 3.471619252004484*^9}},
 CellLabel->"In[109]:="],

Cell[BoxData[
 RowBox[{"nullmatrix", "[", "0", "]"}]], "Input",
 CellChangeTimes->{3.471619282090839*^9},
 CellLabel->"In[110]:="],

Cell[BoxData[
 RowBox[{"VectorQ", "[", 
  RowBox[{"nullmatrix", "[", "0", "]"}], "]"}]], "Input",
 CellLabel->"In[111]:="],

Cell[BoxData[
 RowBox[{"MatrixQ", "[", 
  RowBox[{"nullmatrix", "[", "0", "]"}], "]"}]], "Input",
 CellLabel->"In[112]:="],

Cell[BoxData[
 RowBox[{"VectorQ", "[", 
  RowBox[{"matrix", "[", "a", "]"}], "]"}]], "Input",
 CellLabel->"In[143]:="],

Cell[BoxData[
 RowBox[{"MatrixQ", "[", 
  RowBox[{"matrix", "[", "a", "]"}], "]"}]], "Input",
 CellLabel->"In[148]:="],

Cell[BoxData[
 RowBox[{"matrix", "[", 
  RowBox[{"a", ",", "1", ",", "5"}], "]"}]], "Input",
 CellLabel->"In[113]:="],

Cell[BoxData[
 RowBox[{"VectorQ", "[", 
  RowBox[{"matrix", "[", 
   RowBox[{"a", ",", "1", ",", "5"}], "]"}], "]"}]], "Input",
 CellLabel->"In[114]:="],

Cell[BoxData[
 RowBox[{"MatrixQ", "[", 
  RowBox[{"matrix", "[", 
   RowBox[{"a", ",", "1", ",", "5"}], "]"}], "]"}]], "Input",
 CellLabel->"In[115]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Basis and cobasis of gl(n,K)", "Subsubsection",
 CellChangeTimes->{{3.471620460731976*^9, 3.471620462654108*^9}, 
   3.471678856139187*^9}],

Cell[TextData[{
 "The vector space of the general linear Lie algebra gl(n,K) over the field K \
has dimension ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "2"], TraditionalForm]]],
 ": it is the space of all square matrices of order n. The standard basis \
consists of all matrices with only one element 1 and all the others 0:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"basismatrix", "[", 
   RowBox[{"i_", ",", "j_", ",", 
    RowBox[{"n_:", "dim"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "l"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"i", "<", "1"}], "||", 
        RowBox[{"j", "<", "1"}], "||", 
        RowBox[{"i", ">", "n"}], "||", 
        RowBox[{"j", ">", "n"}]}], ",", " ", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<Incorrect indices!\>\"", "]"}], ";", " ", 
        RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"KroneckerDelta", "[", 
         RowBox[{"i", ",", "k"}], "]"}], "*", 
        RowBox[{"KroneckerDelta", "[", 
         RowBox[{"j", ",", "l"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "n"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"l", ",", "n"}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.471673897811719*^9, 3.471674073720191*^9}, 
   3.471674124987087*^9},
 CellLabel->"In[12]:="],

Cell["The standard basis:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"glbasis", "[", 
   RowBox[{"n_:", "dim"}], "]"}], " ", ":=", " \t\t", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"basismatrix", "[", 
       RowBox[{"i", ",", "j", ",", "n"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "n"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"j", ",", "n"}], "}"}]}], "]"}], ",", "1"}], "]"}]}]], "Input",\

 InitializationCell->True,
 CellChangeTimes->{
  3.471672228424788*^9, {3.471673070137601*^9, 3.471673092484916*^9}},
 CellLabel->"In[13]:="],

Cell[BoxData[
 RowBox[{"glbasis", "[", "]"}]], "Input",
 CellChangeTimes->{{3.471672406554479*^9, 3.471672413039237*^9}, 
   3.471673242215357*^9},
 CellLabel->"In[155]:="],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"MatrixForm", ",", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.471672437094405*^9, 3.471672458723687*^9}},
 CellLabel->"In[156]:="],

Cell["\<\
The corresponding dual basis consists of the linear forms which  yield the \
element  m[[i,j]] of the matrix m:\
\>", "Text",
 CellChangeTimes->{{3.471674218720386*^9, 3.471674221967695*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cobasis", "[", 
    RowBox[{"i_", ",", "j_", ",", 
     RowBox[{"n_:", "dim"}]}], "]"}], "[", "m_", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", "l", ",", " ", 
      RowBox[{"h", "=", " ", "n"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"i", "<", "1"}], "||", 
        RowBox[{"j", "<", "1"}], "||", 
        RowBox[{"i", ">", "h"}], "||", 
        RowBox[{"j", ">", "h"}], "||", 
        RowBox[{
         RowBox[{"Dimensions", "[", "m", "]"}], "\[NotEqual]", 
         RowBox[{"{", 
          RowBox[{"h", ",", "h"}], "}"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<Incorrect indices!\>\"", "]"}], ";", " ", 
        RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"KroneckerDelta", "[", 
         RowBox[{"i", ",", "k"}], "]"}], "*", 
        RowBox[{"KroneckerDelta", "[", 
         RowBox[{"j", ",", "l"}], "]"}], "*", 
        RowBox[{"m", "[", 
         RowBox[{"[", 
          RowBox[{"k", ",", "l"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "n"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"l", ",", "1", ",", "n"}], "}"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.47167427536679*^9, 3.471674302470985*^9}, {
   3.471674627359831*^9, 3.471674649923244*^9}, 3.471674856261707*^9, {
   3.471674969861473*^9, 3.471675003027791*^9}, {3.471675097439343*^9, 
   3.471675124508047*^9}, {3.471675213407961*^9, 3.471675236243935*^9}},
 CellLabel->"In[14]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Tests, examples", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"basismatrix", "[", 
   RowBox[{"2", ",", "3"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[99]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"glbasis", "[", "5", "]"}], "[", 
   RowBox[{"[", "24", "]"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{3.471677842413086*^9},
 CellLabel->"In[162]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"glbasis", "[", "]"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.471673649737581*^9, 3.471673658159495*^9}},
 CellLabel->"In[76]:="],

Cell[BoxData[
 RowBox[{"basismatrix", "[", 
  RowBox[{"1", ",", "4", ",", "3"}], "]"}]], "Input",
 CellChangeTimes->{{3.471674445032219*^9, 3.471674451027346*^9}},
 CellLabel->"In[106]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobasis", "[", 
   RowBox[{"2", ",", "3"}], "]"}], "[", 
  RowBox[{"basismatrix", "[", 
   RowBox[{"2", ",", "3"}], "]"}], "]"}]], "Input",
 CellLabel->"In[177]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobasis", "[", 
   RowBox[{"2", ",", "3"}], "]"}], "[", 
  RowBox[{"basismatrix", "[", 
   RowBox[{"1", ",", "3"}], "]"}], "]"}]], "Input",
 CellLabel->"In[178]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobasis", "[", 
   RowBox[{"2", ",", "4"}], "]"}], "[", 
  RowBox[{"basismatrix", "[", 
   RowBox[{"1", ",", "3"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471674710768253*^9, 3.471674727756806*^9}},
 CellLabel->"In[179]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobasis", "[", 
   RowBox[{"2", ",", "3"}], "]"}], "[", 
  RowBox[{"basismatrix", "[", 
   RowBox[{"1", ",", "i"}], "]"}], "]"}]], "Input",
 CellLabel->"In[180]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobasis", "[", 
   RowBox[{"2", ",", "3"}], "]"}], "[", 
  RowBox[{"basismatrix", "[", 
   RowBox[{"2", ",", "i"}], "]"}], "]"}]], "Input",
 CellLabel->"In[181]:="],

Cell["\<\
If i,j are not specified, the evaluation gives the correct symbolic result:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobasis", "[", 
   RowBox[{"2", ",", "3"}], "]"}], "[", 
  RowBox[{"basismatrix", "[", 
   RowBox[{"i", ",", "j"}], "]"}], "]"}]], "Input",
 CellLabel->"In[182]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobasis", "[", 
   RowBox[{"i", ",", "j"}], "]"}], "[", 
  RowBox[{"basismatrix", "[", 
   RowBox[{"2", ",", "3"}], "]"}], "]"}]], "Input",
 CellLabel->"In[183]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"basismatrix", "[", 
   RowBox[{"2", ",", "3"}], "]"}], "\[LeftDoubleBracket]", 
  RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]], "Input",
 CellChangeTimes->{{3.471678329867931*^9, 3.471678343458075*^9}},
 CellLabel->"In[185]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobasis", "[", 
   RowBox[{"i", ",", "j"}], "]"}], "[", 
  RowBox[{"nullmatrix", "[", "]"}], "]"}]], "Input",
 CellLabel->"In[186]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobasis", "[", 
   RowBox[{"i", ",", "j"}], "]"}], "[", 
  RowBox[{"IdentityMatrix", "[", "5", "]"}], "]"}]], "Input",
 CellLabel->"In[187]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobasis", "[", 
   RowBox[{"i", ",", "i"}], "]"}], "[", 
  RowBox[{"IdentityMatrix", "[", "3", "]"}], "]"}]], "Input",
 CellChangeTimes->{3.471675445295272*^9},
 CellLabel->"In[188]:="],

Cell[BoxData[
 RowBox[{"%", "/.", " ", 
  RowBox[{"i", " ", "\[Rule]", " ", "3"}]}]], "Input",
 CellLabel->"In[189]:="],

Cell[BoxData[
 RowBox[{"Sum", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"cobasis", "[", 
     RowBox[{"i", ",", "j"}], "]"}], "[", 
    RowBox[{"matrix", "[", "a", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.471676481392816*^9, 3.471676482381555*^9}, {
  3.471676512384833*^9, 3.471676606671586*^9}},
 CellLabel->"In[190]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobasis", "[", 
   RowBox[{"i", ",", "j"}], "]"}], "[", 
  RowBox[{"basismatrix", "[", 
   RowBox[{"i", ",", "j"}], "]"}], "]"}]], "Input",
 CellLabel->"In[191]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellLabel->"In[192]:="],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"i", " ", "\[Rule]", "1"}], ",", " ", 
    RowBox[{"j", " ", "\[Rule]", "2"}]}], "}"}]}]], "Input",
 CellLabel->"In[144]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrix", "[", "b", "]"}], " ", "\[Equal]", "  ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"basismatrix", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "*", 
     RowBox[{
      RowBox[{"cobasis", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "[", 
      RowBox[{"matrix", "[", "b", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "dim"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.471678971390281*^9, 3.471679175860933*^9}, {
  3.471679235508284*^9, 3.471679238003348*^9}},
 CellLabel->"In[198]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The structure constants", "Subsubsection",
 CellChangeTimes->{{3.471679315403093*^9, 3.471679317390734*^9}, 
   3.471705721028319*^9}],

Cell["\<\
are the coefficients of the commutator of the basis elements:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"strconst", "[", 
   RowBox[{"i_", ",", "j_", ",", "r_", ",", "s_", ",", "u_", ",", "v_", ",", 
    RowBox[{"n_:", "dim"}]}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"cobasis", "[", 
    RowBox[{"i", ",", "j"}], "]"}], "[", 
   RowBox[{"commute", "[", 
    RowBox[{
     RowBox[{"basismatrix", "[", 
      RowBox[{"r", ",", "s", ",", "n"}], "]"}], ",", 
     RowBox[{"basismatrix", "[", 
      RowBox[{"u", ",", "v", ",", "n"}], "]"}]}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[15]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"strconst", "[", 
     RowBox[{"i", ",", "j", ",", "dim", ",", "1", ",", "1", ",", "1"}], "]"}],
     ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", " ", "dim"}], "}"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[47]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The Killing form of the general linear Lie algebra", "Subsubsection"],

Cell["\<\
Any element of the Lie algebra defines a linear endomorphism of the Lie \
algebra:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ad", "[", "a_", "]"}], "[", "x_", "]"}], " ", ":=", " ", 
  RowBox[{"commute", "[", 
   RowBox[{"a", ",", "x"}], "]"}]}]], "Input",
 CellLabel->"In[48]:="],

Cell[TextData[{
 "The correspondence a \[RightTeeArrow] ad[a] is called the ",
 StyleBox["adjoint representation",
  FontColor->RGBColor[0, 0, 1]],
 " of the Lie algebra."
}], "Text"],

Cell[TextData[{
 "The ",
 StyleBox["Killing form",
  FontColor->RGBColor[0, 0, 1]],
 ", or trace form, is the trace of the composition: killing[a, b] := \
trace[ad[a]\[SmallCircle] ad[b]], where trace[C] denotes the trace of the \
linear endomorphism C. In case of the general linear Lie algebra this leads to"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"glkilling", "[", 
   RowBox[{"a_", ",", " ", "b_", ",", " ", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", "\n", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"cobasis", "[", 
        RowBox[{"i", ",", " ", "j", ",", "n"}], "]"}], "[", " ", 
       RowBox[{"commute", "[", 
        RowBox[{"a", ",", " ", 
         RowBox[{"commute", "[", 
          RowBox[{"b", ",", 
           RowBox[{"basismatrix", "[", 
            RowBox[{"i", ",", " ", "j", ",", "n"}], "]"}]}], "]"}]}], "]"}], 
       "]"}], ",", "\n", "        ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "1", ",", " ", "n"}], "}"}]}], "]"}], ",", " ", 
    
    RowBox[{"{", 
     RowBox[{"j", ",", " ", "1", ",", " ", "n"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.471703319167911*^9, 3.471703330299437*^9}},
 CellLabel->"In[16]:="],

Cell[BoxData[
 RowBox[{"glkilling", "[", 
  RowBox[{
   RowBox[{"basismatrix", "[", 
    RowBox[{"2", ",", "3"}], "]"}], ",", 
   RowBox[{"basismatrix", "[", 
    RowBox[{"2", ",", "3"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{"glkilling", "[", 
  RowBox[{
   RowBox[{"basismatrix", "[", 
    RowBox[{"2", ",", "3"}], "]"}], ",", 
   RowBox[{"basismatrix", "[", 
    RowBox[{"1", ",", "3"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.471703385463703*^9, 3.471703393304228*^9}},
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"glkilling", "[", 
    RowBox[{
     RowBox[{"basismatrix", "[", 
      RowBox[{"1", ",", "a", ",", "2"}], "]"}], ",", 
     RowBox[{"basismatrix", "[", 
      RowBox[{"1", ",", "b", ",", "2"}], "]"}], ",", "2"}], "]"}], " ", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"glkilling", "[", 
    RowBox[{
     RowBox[{"basismatrix", "[", 
      RowBox[{"1", ",", "a", ",", "2"}], "]"}], ",", 
     RowBox[{"basismatrix", "[", 
      RowBox[{"2", ",", "b", ",", "2"}], "]"}], ",", "2"}], "]"}], " ", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[53]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"glkilling", "[", 
    RowBox[{
     RowBox[{"basismatrix", "[", 
      RowBox[{"2", ",", "a", ",", "2"}], "]"}], ",", 
     RowBox[{"basismatrix", "[", 
      RowBox[{"2", ",", "b", ",", "2"}], "]"}], ",", "2"}], "]"}], " ", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[54]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"glkilling", "[", 
    RowBox[{
     RowBox[{"basismatrix", "[", 
      RowBox[{"a", ",", "a", ",", "2"}], "]"}], ",", 
     RowBox[{"basismatrix", "[", 
      RowBox[{"b", ",", "b", ",", "2"}], "]"}], ",", "2"}], "]"}], " ", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[55]:="],

Cell["\<\
The general shape of glkilling as a bilinear or quadratic form can be shown by\
\>", "Text"],

Cell[BoxData[
 RowBox[{"glkilling", "[", 
  RowBox[{
   RowBox[{"matrix", "[", "a", "]"}], ",", 
   RowBox[{"matrix", "[", "b", "]"}]}], "]"}]], "Input",
 CellLabel->"In[56]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellLabel->"In[57]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"glkilling", "[", 
   RowBox[{
    RowBox[{"matrix", "[", "a", "]"}], ",", " ", 
    RowBox[{"matrix", "[", "a", "]"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[58]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The elements of the center", "Subsubsection"],

Cell["\<\
By definition, the center of the Lie algebra is the kernel of the adjoint \
representation; with other words, it consists of all elements a with \
commute[a,x] = nullmatrix for all elements x of the Lie algebra. By\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "5"}], ";", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"commute", "[", 
         RowBox[{
          RowBox[{"basismatrix", "[", 
           RowBox[{"i", ",", "j"}], "]"}], ",", 
          RowBox[{"matrix", "[", "x", "]"}]}], "]"}], "==", "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "5"}], "}"}]}], "]"}], "]"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"matrix", "[", "x", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.471703674184979*^9, 3.47170367959235*^9}},
 CellLabel->"In[65]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrix", "[", "x", "]"}], "/.", 
  RowBox[{"Flatten", "[", "%", "]"}]}]], "Input",
 CellChangeTimes->{{3.471703715565737*^9, 3.471703735669706*^9}, {
  3.471704405760794*^9, 3.471704413664773*^9}},
 CellLabel->"In[66]:="],

Cell[BoxData[
 RowBox[{"%", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.471703746385361*^9, 3.47170375232846*^9}, {
   3.471703799629873*^9, 3.471703816555242*^9}, {3.47170390952517*^9, 
   3.471703932099366*^9}, 3.471704449647994*^9},
 CellLabel->"In[67]:="],

Cell["\<\
one has an example that it consists of all scalar multiples of the identity \
matrix:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"zelm", "[", 
   RowBox[{"z_", ",", " ", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"IdentityMatrix", "[", "n", "]"}], "*", "z"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[17]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"zelm", "[", "p", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[63]:="],

Cell["\<\
As well known, the defect subspace of the Killing form of gl(n,K) coincides \
with the center of gl(n,K). Indeed, we solve\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"glkilling", "[", 
        RowBox[{
         RowBox[{"basismatrix", "[", 
          RowBox[{"i", ",", "j"}], "]"}], ",", 
         RowBox[{"matrix", "[", "x", "]"}]}], "]"}], "==", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "5"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"Flatten", "[", 
    RowBox[{"matrix", "[", "x", "]"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[68]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"matrix", "[", "x", "]"}], "/.", 
    RowBox[{"Flatten", "[", "%", "]"}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.47170448037369*^9, 3.471704531266553*^9}},
 CellLabel->"In[69]:="],

Cell["and obtain the center again. Obviously", "Text"],

Cell[BoxData[
 RowBox[{"commute", "[", 
  RowBox[{
   RowBox[{"matrix", "[", "a", "]"}], ",", 
   RowBox[{"zelm", "[", "p", "]"}]}], "]"}]], "Input",
 CellLabel->"In[70]:="],

Cell[BoxData[
 RowBox[{"glkilling", "[", 
  RowBox[{
   RowBox[{"matrix", "[", "a", "]"}], ",", " ", 
   RowBox[{"zelm", "[", "p", "]"}]}], "]"}]], "Input",
 CellLabel->"In[71]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2 Orthonormalization", "Subsection"],

Cell["\<\
Applying orthonormalization with respect to the Killing form  on any basis of \
a Lie algebra of matrices we find the rank and the index of the Killing form \
which are fundamental invariants of the Lie algebra.  The orthonormalization \
procedure defined in this section can be applied to arbitrary symmetric \
bilinear forms on matrix spaces; it is independent of the Lie algebra \
structure.
Here is a matrix version of euvec`outzero (from euvec.m, in [2]), which we \
need for the orthonormalization procedure; the procedure deletes the null \
matrices of the list b of matrices:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrixoutzero", "[", "b_List", "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"v", "=", " ", 
       RowBox[{"{", "}"}]}], ",", " ", 
      RowBox[{"l", " ", "=", " ", 
       RowBox[{"Length", "[", "b", "]"}]}], ",", " ", 
      RowBox[{"k", " ", "=", " ", 
       RowBox[{"Length", "[", 
        RowBox[{"b", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ",", "i"}], "}"}], ",", 
    "\n", "\t\t\t", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", " ", "=", " ", "1"}], ",", " ", 
       RowBox[{"i", "<=", " ", "l"}], ",", " ", 
       RowBox[{"i", "++"}], ",", " ", "\n", "\t\t", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Not", "[", 
          RowBox[{
           RowBox[{"smoothing", "[", 
            RowBox[{"b", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}], " ", "==", " ", 
           RowBox[{"nullmatrix", "[", "k", "]"}]}], "]"}], ",", "\n", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"v", ",", " ", 
           RowBox[{"b", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
         RowBox[{"Null", "[", "]"}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"v", ",", " ", 
           RowBox[{"b", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}]}], "]"}], ";", 
     " ", 
     RowBox[{"Return", "[", "v", "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.471704732364013*^9, 3.471704733377854*^9}},
 CellLabel->"In[18]:="],

Cell["\<\
The following module is contained in the package pseuvec.m in [2]:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"normalize", "[", 
   RowBox[{"v_", ",", 
    RowBox[{"prod_:", "glkilling"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "=", 
       RowBox[{"Simplify", "[", 
        RowBox[{"prod", "[", 
         RowBox[{"v", ",", "v"}], "]"}], "]"}]}], ",", "w"}], "}"}], ",", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"a", "\[Equal]", "0"}], ",", 
       RowBox[{"w", "=", "v"}], ",", 
       RowBox[{"w", "=", 
        RowBox[{"v", "/", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"Abs", "[", "a", "]"}], "]"}]}]}], ",", 
       RowBox[{"w", "=", 
        RowBox[{"v", "/", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"Abs", "[", "a", "]"}], "]"}]}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", "w", "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[19]:="],

Cell["\<\
We created  the following procedure matrixorthonorm from orthonorm, pseuvec.m \
(contained in [2]),  replacing outzero by matrixoutzero:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "matrixorthonorm", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"innerprod", "\[Rule]", "glkilling"}], ",", 
     RowBox[{"normed", "\[Rule]", "True"}], ",", 
     RowBox[{"print", "\[Rule]", "False"}], ",", 
     RowBox[{"neglect", "\[Rule]", 
      RowBox[{"-", "10"}]}]}], "}"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.47170478950985*^9},
 CellLabel->"In[20]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrixorthonorm", "[", 
   RowBox[{"b_List", ",", "opts___"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"v", ",", "w", ",", "va", ",", "vb", ",", "l", ",", 
      RowBox[{"ort", "=", 
       RowBox[{"{", "}"}]}], ",", "i", ",", "j", ",", "f", ",", "h", ",", 
      "sm", ",", "aus", ",", "prod", ",", "nor", ",", "pr", ",", "bn", ",", 
      "follow", ",", "iso", ",", "control"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"prod", ",", "nor", ",", "pr", ",", "bn"}], "}"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"innerprod", ",", "normed", ",", "print", ",", "neglect"}], 
         "}"}], "/.", 
        RowBox[{"{", "opts", "}"}]}], "/.", 
       RowBox[{"Options", "[", "matrixorthonorm", "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"f", "[", "h_", "]"}], ":=", 
      RowBox[{"smoothing", "[", 
       RowBox[{"h", ",", 
        RowBox[{"10", "^", "bn"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sm", "[", "aus_", "]"}], ":=", 
      RowBox[{"MapAll", "[", 
       RowBox[{"f", ",", "aus"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"w", "=", 
      RowBox[{"matrixoutzero", "[", 
       RowBox[{"sm", "[", "b", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Label", "[", "follow", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"l", "=", 
      RowBox[{"Length", "[", "w", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"l", "\[Equal]", "0"}], ",", 
       RowBox[{"Goto", "[", "control", "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "l"}], ",", 
       RowBox[{"i", "++"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Not", "[", 
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{"sm", "[", 
             RowBox[{"prod", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", 
               RowBox[{"w", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
           "\[Equal]", "0"}], "]"}], ",", 
         RowBox[{
          RowBox[{"AppendTo", "[", 
           RowBox[{"ort", ",", 
            RowBox[{"w", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"pr", "\[Equal]", "True"}], ",", 
            RowBox[{"Print", "[", 
             RowBox[{
              RowBox[{"w", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "//", "MatrixForm"}], "]"}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"v", "=", 
           RowBox[{"Simplify", "[", 
            RowBox[{"sm", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"w", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "-", 
                RowBox[{
                 RowBox[{"w", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "*", 
                 RowBox[{
                  RowBox[{"prod", "[", 
                   RowBox[{
                    RowBox[{"w", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"w", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "/", 
                  RowBox[{"prod", "[", 
                   RowBox[{
                    RowBox[{"w", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"w", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"w", "=", 
           RowBox[{"matrixoutzero", "[", "v", "]"}]}], ";", " ", 
          RowBox[{"Goto", "[", "follow", "]"}]}], ",", "Null", ",", 
         RowBox[{
          RowBox[{"AppendTo", "[", 
           RowBox[{"ort", ",", 
            RowBox[{"w", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"pr", "\[Equal]", "True"}], ",", 
            RowBox[{"Print", "[", 
             RowBox[{
              RowBox[{"w", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "//", "MatrixForm"}], "]"}]}], 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"v", "=", 
           RowBox[{"Simplify", "[", 
            RowBox[{"sm", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"w", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], "-", 
                RowBox[{
                 RowBox[{"w", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "*", 
                 RowBox[{
                  RowBox[{"prod", "[", 
                   RowBox[{
                    RowBox[{"w", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"w", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "/", 
                  RowBox[{"prod", "[", 
                   RowBox[{
                    RowBox[{"w", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", 
                    RowBox[{"w", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}]}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "l"}], "}"}]}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"w", "=", 
           RowBox[{"matrixoutzero", "[", "v", "]"}]}], ";", " ", 
          RowBox[{"Goto", "[", "follow", "]"}]}]}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Label", "[", "iso", "]"}], ";", 
     RowBox[{"l", "=", 
      RowBox[{"Length", "[", "w", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"l", "\[Equal]", "0"}], ",", 
       RowBox[{"Goto", "[", "control", "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"v", "=", "w"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"l", "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"ort", ",", 
          RowBox[{"v", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}], ";", " ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"pr", "\[Equal]", "True"}], ",", 
          RowBox[{"Print", "[", 
           RowBox[{
            RowBox[{"v", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "//", "MatrixForm"}], "]"}]}], 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Goto", "[", "control", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "l"}], ",", 
       RowBox[{"i", "++"}], ",", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", 
          RowBox[{"i", "+", "1"}]}], ",", 
         RowBox[{"j", "\[LessEqual]", "l"}], ",", 
         RowBox[{"j", "++"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"Not", "[", 
            RowBox[{
             RowBox[{"Simplify", "[", 
              RowBox[{"sm", "[", 
               RowBox[{"prod", "[", 
                RowBox[{
                 RowBox[{"v", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"v", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
             "\[Equal]", "0"}], "]"}], ",", 
           RowBox[{
            RowBox[{"va", "=", 
             RowBox[{
              RowBox[{"v", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "-", 
              RowBox[{"v", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"vb", "=", 
             RowBox[{
              RowBox[{"v", "[", 
               RowBox[{"[", "j", "]"}], "]"}], "+", 
              RowBox[{"v", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}]}], ";", " \t\t\t\t", 
            RowBox[{
             RowBox[{"v", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "=", "va"}], ";", 
            RowBox[{
             RowBox[{"v", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "=", "vb"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"w", "=", 
             RowBox[{"matrixoutzero", "[", 
              RowBox[{"Simplify", "[", 
               RowBox[{"sm", "[", "v", "]"}], "]"}], "]"}]}], ";", 
            RowBox[{"Goto", "[", "follow", "]"}]}]}], "]"}]}], "]"}]}], "]"}],
      ";", " \t\t\t", 
     RowBox[{"ort", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"ort", ",", "v"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Label", "[", "control", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"l", "=", 
      RowBox[{"Length", "[", "ort", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"l", "\[Equal]", "0"}], ",", 
       RowBox[{"Return", "[", "ort", "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"nor", "\[Equal]", "True"}], ",", 
       RowBox[{"ort", "=", 
        RowBox[{"sm", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{"normalize", "[", 
             RowBox[{
              RowBox[{"ort", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "prod"}], "]"}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "ort", "]"}]}], "}"}]}], "]"}], "]"}]}]}],
       "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", 
        RowBox[{"l", "-", "1"}]}], ",", 
       RowBox[{"i", "++"}], ",", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", 
          RowBox[{"i", "+", "1"}]}], ",", 
         RowBox[{"j", "\[LessEqual]", "l"}], ",", 
         RowBox[{"j", "++"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"Not", "[", 
            RowBox[{
             RowBox[{"Simplify", "[", 
              RowBox[{"sm", "[", 
               RowBox[{"prod", "[", 
                RowBox[{
                 RowBox[{"ort", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"ort", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
             "\[Equal]", "0"}], "]"}], ",", 
           RowBox[{"Return", "[", 
            RowBox[{
            "Print", "[", 
             "\"\<I cannot orthogonalize the given sequence!\>\"", "]"}], 
            "]"}], ",", "Null", ",", 
           RowBox[{"Return", "[", 
            RowBox[{
            "Print", "[", 
             "\"\<I cannot orthogonalize the given sequence!\>\"", "]"}], 
            "]"}]}], "]"}]}], "]"}]}], "]"}], ";", " \t", 
     RowBox[{"Return", "[", "ort", "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[21]:="],

Cell[CellGroupData[{

Cell["Tests", "Subsubsection"],

Cell[BoxData[
 RowBox[{"normalize", "[", 
  RowBox[{
   RowBox[{"IdentityMatrix", "[", "5", "]"}], "*", "a"}], "]"}]], "Input",
 CellLabel->"In[73]:="],

Cell[BoxData[
 RowBox[{"glkilling", "[", 
  RowBox[{"%", ",", "%"}], "]"}]], "Input",
 CellLabel->"In[74]:="],

Cell[BoxData[
 RowBox[{"normalize", "[", 
  RowBox[{
   RowBox[{"nullmatrix", "[", "5", "]"}], "*", "a"}], "]"}]], "Input",
 CellLabel->"In[75]:="],

Cell[BoxData[
 RowBox[{"normalize", "[", 
  RowBox[{
   RowBox[{"basismatrix", "[", 
    RowBox[{"1", ",", "3"}], "]"}], "*", "a"}], "]"}]], "Input",
 CellLabel->"In[76]:="],

Cell[BoxData[
 RowBox[{"glkilling", "[", 
  RowBox[{"%", ",", "%"}], "]"}]], "Input",
 CellLabel->"In[77]:="],

Cell[BoxData[
 RowBox[{"normalize", "[", 
  RowBox[{
   RowBox[{"basismatrix", "[", 
    RowBox[{"1", ",", "1"}], "]"}], "*", "a"}], "]"}]], "Input",
 CellLabel->"In[78]:="],

Cell[BoxData[
 RowBox[{"glkilling", "[", 
  RowBox[{"%", ",", "%"}], "]"}]], "Input",
 CellLabel->"In[79]:="],

Cell[BoxData[
 RowBox[{"tlist", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"basismatrix", "[", 
     RowBox[{"i", ",", " ", "i"}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "dim"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[80]:="],

Cell[BoxData[
 RowBox[{"matrixorthonorm", "[", 
  RowBox[{"tlist", ",", " ", 
   RowBox[{"print", " ", "\[Rule]", " ", "True"}]}], "]"}]], "Input",
 CellLabel->"In[81]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"glkilling", "[", 
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
      RowBox[{"%", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "dim"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"j", ",", " ", "dim"}], "}"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[82]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
2.3 An orthonormal basis of the general linear Lie algebra gl(n,K)\
\>", "Subsection"],

Cell["\<\
To apply the procedure orthonorm to the general case we rename the Killing \
form in an appropriate way\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sprod", "[", "n_", "]"}], "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], " ", ":=", " ", 
  RowBox[{"glkilling", "[", 
   RowBox[{"a", ",", "b", ",", "n"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.471672554122835*^9},
 CellLabel->"In[22]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sprod", "[", "2", "]"}], "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", 
        SqrtBox["2"]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", 
        SqrtBox["2"]], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[84]:="],

Cell["The standard basis is not orthogonal:", "Text",
 CellChangeTimes->{{3.47179096878125*^9, 3.47179098684375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sprod", "[", "3", "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"glbasis", "[", "3", "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"glbasis", "[", "3", "]"}], "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "9"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "9"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[85]:="],

Cell["Now we orthogonalize it:", "Text",
 CellChangeTimes->{{3.47179102375*^9, 3.471791036390625*^9}}],

Cell[BoxData[
 RowBox[{"matrixorthonorm", "[", 
  RowBox[{
   RowBox[{"glbasis", "[", "3", "]"}], ",", 
   RowBox[{"innerprod", " ", "->", 
    RowBox[{"sprod", "[", "3", "]"}]}]}], "]"}]], "Input",
 CellLabel->"In[86]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"test3", " ", "=", " ", "%"}], ";"}]], "Input",
 CellLabel->"In[87]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"test3", "[", 
     RowBox[{"[", "i", "]"}], "]"}], "//", "MatrixForm"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"i", ",", " ", 
     RowBox[{"Length", "[", "test3", "]"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[88]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sprod", "[", "3", "]"}], "[", 
     RowBox[{
      RowBox[{"test3", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"test3", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", 
      RowBox[{"Length", "[", "test3", "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", " ", 
      RowBox[{"Length", "[", "test3", "]"}]}], "}"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[89]:="],

Cell["\<\
The last element is isotropic; it is the basis of the diagonal (the center). \
Generally, the standard basis is far from being orthogonal:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"dim", " ", "=", "5"}]], "Input",
 CellChangeTimes->{{3.471705236856293*^9, 3.47170523711781*^9}, {
  3.471791130859375*^9, 3.471791133921875*^9}},
 CellLabel->"In[91]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"glkilling", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"glbasis", "[", "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"glbasis", "[", "]"}], "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"glbasis", "[", "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", 
       RowBox[{"glbasis", "[", "]"}], "]"}]}], "}"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[90]:="],

Cell["\<\
Here and in the following cell we used the global definition of dim, and for \
the next cell we remember that glkilling is the default inner product.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"matrixorthonorm", "[", 
   RowBox[{"glbasis", "[", "]"}], "]"}], "]"}]], "Input",
 CellLabel->"In[92]:="],

Cell[TextData[{
 StyleBox["At 1999, Mathematica",
  FontSlant->"Italic"],
 " needed 185 s for the orthonormalization. Now, on a Dell Precision 370 from \
2004, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v. 7.0 needed  17 s only."
}], "Text",
 CellChangeTimes->{{3.471705341698075*^9, 3.471705437396537*^9}, {
  3.47170547277477*^9, 3.471705506558878*^9}}],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[93]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"glortho", "=", " ", 
   RowBox[{"%%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[94]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"glortho", "[", 
     RowBox[{"[", "i", "]"}], "]"}], "//", "MatrixForm"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"i", ",", "25"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[95]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"glkilling", "[", 
    RowBox[{
     RowBox[{"glortho", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"glortho", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "25"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "25"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[96]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.4 The special linear Lie algebra sl(n,K)", "Subsection",
 CellChangeTimes->{{3.471706604728207*^9, 3.471706606845981*^9}, 
   3.471760377906172*^9}],

Cell["\<\
The special linear Lie algebra sl(n,K) consists of all square matrices of \
order n with trace zero. It is the kernel of the trace map \
\>", "Text"],

Cell["\<\
trace:a\[Element]gl(n,K) \[RightTeeArrow] trace(a) \[Epsilon] K = gl(1,K)\
\>", "Text",
 TextAlignment->Center],

Cell["\<\
which is an homomorphism of Lie algebras, and therefore an ideal within the \
general linear Lie algebra. From the definitions it follows easily that the  \
Killing form of any ideal is the restriction of the Killing form of the whole \
Lie algebra. Thus,  for finding the index of the Killing form of sl(n, K) we \
first define a basis of s(ln, K), and then orthonormalize it with respect to \
glkilling.\
\>", "Text",
 CellChangeTimes->{3.471705838055804*^9}],

Cell[CellGroupData[{

Cell["A basis of sl(n,K)", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"slbasismatrix", "[", 
    RowBox[{"i_", ",", " ", "j_", ",", 
     RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", "\n", "\t", 
   RowBox[{
    RowBox[{"basismatrix", "[", 
     RowBox[{"i", ",", "j", ",", "n"}], "]"}], "/;", 
    RowBox[{"i", "!=", " ", "j"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"slbasismatrix", "[", 
   RowBox[{"i_", ",", " ", "j_", ",", " ", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", "\n", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"basismatrix", "[", 
      RowBox[{"i", ",", "j", ",", "n"}], "]"}], "-", "\t", 
     RowBox[{"basismatrix", "[", 
      RowBox[{"n", ",", "n", ",", "n"}], "]"}]}], ")"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"i", "==", " ", "j"}], "&&", " ", 
     RowBox[{"j", "<", "n"}]}], ")"}]}]}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[23]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"slbasis", "[", 
   RowBox[{"n_:", "dim"}], "]"}], " ", ":=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"slbasismatrix", "[", 
         RowBox[{"i", ",", "j", ",", "n"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", 
          RowBox[{"n", "-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", " ", "n"}], "}"}]}], "]"}], ",", "1"}], "]"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"slbasismatrix", "[", 
       RowBox[{"n", ",", "h", ",", "n"}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"h", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[25]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"slbasisMF", "[", 
   RowBox[{"n_:", "dim"}], "]"}], " ", ":=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"slbasismatrix", "[", 
          RowBox[{"i", ",", "j", ",", "n"}], "]"}], "//", "MatrixForm"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", " ", 
          RowBox[{"n", "-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", " ", "n"}], "}"}]}], "]"}], ",", "1"}], "]"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"slbasismatrix", "[", 
        RowBox[{"n", ",", "h", ",", "n"}], "]"}], "//", "MatrixForm"}], ",", 
      " ", 
      RowBox[{"{", 
       RowBox[{"h", ",", 
        RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[26]:="],

Cell[BoxData[
 RowBox[{"slbasis", "[", "2", "]"}]], "Input",
 CellLabel->"In[92]:="],

Cell[BoxData[
 RowBox[{"slbasis", "[", "3", "]"}]], "Input",
 CellLabel->"In[254]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "5"}], ";"}]], "Input",
 CellChangeTimes->{{3.471757762439033*^9, 3.471757766877332*^9}},
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{"slbasis", "[", "]"}]], "Input",
 CellChangeTimes->{{3.471757151715298*^9, 3.471757196734491*^9}, {
   3.471757469261331*^9, 3.471757472991516*^9}, 3.471757776250224*^9},
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471757556203108*^9, 3.47175755980646*^9}},
 CellLabel->"In[53]:="],

Cell[BoxData[
 RowBox[{"glkilling", "[", 
  RowBox[{"%", ",", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.471757569417267*^9, 3.471757580869153*^9}},
 CellLabel->"In[54]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Orthonormalization of the basis", "Subsubsection"],

Cell[BoxData[
 RowBox[{"matrixorthonorm", "[", 
  RowBox[{
   RowBox[{"slbasis", "[", "2", "]"}], ",", 
   RowBox[{"innerprod", " ", "\[Rule]", " ", 
    RowBox[{"sprod", "[", "2", "]"}]}]}], "]"}]], "Input",
 CellLabel->"In[65]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"sprod", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"%", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"%", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[66]:="],

Cell[BoxData[
 RowBox[{"matrixorthonorm", "[", 
  RowBox[{
   RowBox[{"slbasis", "[", "3", "]"}], ",", 
   RowBox[{"innerprod", " ", "\[Rule]", " ", 
    RowBox[{"sprod", "[", "3", "]"}]}]}], "]"}]], "Input",
 CellLabel->"In[67]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"stest3", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.471760262753688*^9},
 CellLabel->"In[68]:="],

Cell[BoxData[
 RowBox[{"Length", "[", "stest3", "]"}]], "Input",
 CellLabel->"In[69]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"glkilling", "[", 
     RowBox[{
      RowBox[{"stest3", "[", 
       RowBox[{"[", "a", "]"}], "]"}], ",", " ", 
      RowBox[{"stest3", "[", 
       RowBox[{"[", "b", "]"}], "]"}], ",", "3"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "8"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"b", ",", "8"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[70]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"matrixorthonorm", "[", 
   RowBox[{
    RowBox[{"slbasis", "[", "5", "]"}], ",", " ", 
    RowBox[{"innerprod", " ", "\[Rule]", " ", 
     RowBox[{"sprod", "[", "5", "]"}]}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.471757273161236*^9, {3.471757964560826*^9, 3.471757984156648*^9}, {
   3.471758024055842*^9, 3.471758029695397*^9}},
 CellLabel->"In[57]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[58]:="],

Cell[TextData[{
 "This calculation of test5 on the Dell Inspiron 3200 under Linux, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 4.0,  needed about 175 s. Now, on the Dell  Precision 370 under ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 7.0, SuSE Linux 11.1,  we needed 16 s only."
}], "Text",
 CellChangeTimes->{{3.471758080871562*^9, 3.471758182820753*^9}, {
  3.47176033260855*^9, 3.471760342154076*^9}, {3.47179132871875*^9, 
  3.4717913321875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"stest5", " ", "=", " ", 
   RowBox[{"%%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[59]:="],

Cell[BoxData[
 RowBox[{"Length", "[", "stest5", "]"}]], "Input",
 CellLabel->"In[60]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"glkilling", "[", 
     RowBox[{
      RowBox[{"stest5", "[", 
       RowBox[{"[", "a", "]"}], "]"}], ",", 
      RowBox[{"stest5", "[", 
       RowBox[{"[", "b", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "24"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "24"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",\

 CellLabel->"In[61]:="],

Cell[TextData[{
 "The index of the Killing form of sl(5,R) is 10. As for all semisimple Lie \
algebras the form is non degenerate. The ",
 StyleBox["Cartan index",
  FontColor->RGBColor[0, 0, 1]],
 " of a semi simple real Lie algebra is defined as"
}], "Text"],

Cell["CartanIndex := pos -neg,", "Text",
 TextAlignment->Center],

Cell["\<\
where pos denotes the number of the spacelike and neg the number of the \
timelike elements of an orthogonalized basis. Obviously one has\
\>", "Text"],

Cell["CartanIndex = dimension - 2 neg", "Text",
 CellChangeTimes->{{3.471791380640625*^9, 3.471791383828125*^9}},
 TextAlignment->Center],

Cell["\<\
The result CartanIndex[sl(5, R)] = 4 coincides with the value given in [3], \
p. 27. 
Parts of the orthonormal basis stest5 can be printed by\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"printstest5", "[", 
   RowBox[{"a_", ",", " ", "b_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"stest5", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "//", "MatrixForm"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", "a", ",", "b"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[62]:="],

Cell[BoxData[
 RowBox[{"printstest5", "[", 
  RowBox[{"1", ",", " ", "10"}], "]"}]], "Input",
 CellLabel->"In[63]:="]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3 The orthogonal Lie algebras o(n) ", "Section"],

Cell[CellGroupData[{

Cell["3.1 Basis of o(n), general element", "Subsection",
 CellChangeTimes->{3.471760528572738*^9}],

Cell["\<\
The orthogonal Lie algebra o(n) is the space of all skew symmetric matrices \
of order n. The standard  basis of o(n) is: \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"obm", "[", 
   RowBox[{"i_", ",", " ", "j_", ",", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"basismatrix", "[", 
     RowBox[{"i", ",", " ", "j", ",", "n"}], "]"}], " ", "-", " ", 
    RowBox[{"basismatrix", "[", 
     RowBox[{"j", ",", " ", "i", ",", " ", "n"}], "]"}]}], "/;", 
   RowBox[{"i", " ", "<", " ", "j"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[26]:="],

Cell[BoxData["dim"], "Input",
 CellChangeTimes->{{3.471760665473553*^9, 3.471760665887529*^9}},
 CellLabel->"In[73]:="],

Cell["obm[1,2,3]", "Input",
 PageWidth->Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[71]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"obm", "[", 
   RowBox[{"3", ",", "4"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[72]:="],

Cell["obm[2,3,3]", "Input",
 PageWidth->Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[74]:="],

Cell["obm[i, j, n] will not be evaluated for invalid arguments:", "Text"],

Cell["obm[2,2,3]", "Input",
 PageWidth->Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[75]:="],

Cell["The standard basis is ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"obasis", "[", 
   RowBox[{"n_:", "dim"}], "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"obm", "[", 
         RowBox[{"i", ",", "j", ",", "n"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"i", "+", "1"}], ",", "n"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "n"}], "}"}]}], "]"}], ",", "1"}], "]"}]}]], "Input",\

 InitializationCell->True,
 CellLabel->"In[27]:="],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"MatrixForm", ",", 
   RowBox[{"obasis", "[", "3", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.471760725662738*^9, 3.471760752894087*^9}},
 CellLabel->"In[78]:="],

Cell["The abitrary element of the orthogonal Lie algebra o(n):  ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"oelm", "[", 
   RowBox[{"a_", ",", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"obm", "[", 
        RowBox[{"i", ",", " ", "j", ",", "n"}], "]"}], " ", 
       RowBox[{"a", "[", 
        RowBox[{"i", ",", " ", "j"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "1", ",", " ", 
        RowBox[{"j", " ", "-", "1"}]}], "}"}]}], "]"}], ",", " ", "\n", 
    "                 ", 
    RowBox[{"{", 
     RowBox[{"j", ",", " ", "2", ",", " ", "n"}], "}"}]}], "]"}], 
  " "}]], "Input",
 PageWidth->Infinity,
 InitializationCell->True,
 ShowSpecialCharacters->False,
 CellLabel->"In[28]:="],

Cell["oelm[a]//MatrixForm ", "Input",
 PageWidth->Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[79]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2 The Killing form of o(n) ", "Subsection",
 CellChangeTimes->{3.471760604895931*^9}],

Cell["The Killing form:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"okilling", "[", 
   RowBox[{"a_", ",", " ", "b_", ",", " ", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"cobasis", "[", 
        RowBox[{"i", ",", " ", "j", ",", "n"}], "]"}], "[", " ", 
       RowBox[{"Evaluate", "[", 
        RowBox[{"commute", "[", 
         RowBox[{"a", ",", " ", 
          RowBox[{"commute", "[", 
           RowBox[{"b", ",", " ", 
            RowBox[{"obm", "[", 
             RowBox[{"i", ",", " ", "j", ",", " ", "n"}], "]"}]}], "]"}]}], 
         "]"}], "]"}], "]"}], ",", " ", "\n", "    ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "1", ",", " ", 
        RowBox[{"j", " ", "-", " ", "1"}]}], "}"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"j", ",", " ", "2", ",", " ", "n"}], "}"}]}], "]"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellLabel->"In[29]:="],

Cell["\<\
The standard basis is orthogonal; therefore an orthogonalization is not \
necessary. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"okilling", "[", 
  RowBox[{
   RowBox[{"oelm", "[", 
    RowBox[{"a", ",", "6"}], "]"}], ",", 
   RowBox[{"oelm", "[", 
    RowBox[{"b", ",", " ", "6"}], "]"}], ",", "6"}], "]"}]], "Input",
 CellLabel->"In[80]:="],

Cell["\<\
The restriction of glkilling to o(n), n = 2, 3, 4, 6, is conformal to the \
Killingform okilling.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"glkilling", "[", 
  RowBox[{
   RowBox[{"oelm", "[", 
    RowBox[{"a", ",", "6"}], "]"}], ",", 
   RowBox[{"oelm", "[", 
    RowBox[{"b", ",", " ", "6"}], "]"}], ",", "6"}], "]"}]], "Input",
 CellLabel->"In[81]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.471761027665538*^9, 3.471761037118516*^9}},
 CellLabel->"In[82]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "/", 
   RowBox[{"okilling", "[", 
    RowBox[{
     RowBox[{"oelm", "[", 
      RowBox[{"a", ",", "6"}], "]"}], ",", 
     RowBox[{"oelm", "[", 
      RowBox[{"b", ",", " ", "6"}], "]"}], ",", "6"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.471761048959232*^9, 3.47176111373872*^9}},
 CellLabel->"In[83]:="],

Cell["The Lie algebra o(2) is abelian, therefore one has", "Text"],

Cell[BoxData[
 RowBox[{"okilling", "[", 
  RowBox[{
   RowBox[{"oelm", "[", 
    RowBox[{"a", ",", "2"}], "]"}], ",", 
   RowBox[{"oelm", "[", 
    RowBox[{"b", ",", " ", "2"}], "]"}], ",", "2"}], "]"}]], "Input",
 CellLabel->"In[84]:="],

Cell["\<\
Since o(n) for n >2 is semisimple and compact, the Killing forms are negative \
definite, e.g. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"okilling", "[", 
  RowBox[{
   RowBox[{"oelm", "[", "a", "]"}], ",", 
   RowBox[{"oelm", "[", "a", "]"}]}], "]"}]], "Input",
 CellLabel->"In[85]:="],

Cell[" We obtain an orthonormed basis using normalize:", "Text"],

Cell[BoxData[
 RowBox[{"obasis", "[", "]"}]], "Input",
 CellLabel->"In[86]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"normalize", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"obasis", "[", "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", "okilling"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"i", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[87]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"otest5", " ", "=", "%"}], ";"}]], "Input",
 CellLabel->"In[88]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"otest5", "[", 
     RowBox[{"[", "i", "]"}], "]"}], "//", "MatrixForm"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"i", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[89]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"okilling", "[", 
     RowBox[{
      RowBox[{"%%", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
      RowBox[{"%%", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "10"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"j", ",", " ", "10"}], "}"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[90]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4 The pseudo-orthogonal Lie algebras o(n,k)", "Section",
 PageWidth->WindowWidth,
 ShowSpecialCharacters->False,
 FontFamily->"Helvetica"],

Cell[CellGroupData[{

Cell["4.1 Basis, arbitrary element", "Subsection"],

Cell["\<\
The pseudo-orthogonal Lie algebras o(n,k) is the Lie algebra of the \
pseudo-orthogonal group O(n,k), which is the group of all linear \
automorphisms of the n-dimensional real vector space leaving a non degenerate \
symmetric bilinear form of index k invariant. The group O(4,1) is the Lorentz \
group applied in relativity theory. The Lie algebra o(5,1) is the Lie algebra \
of the conformal group of the 3-sphere (M\[ODoubleDot]bius group of the \
3-sphere).The standard basis of o(n, k) is:  \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psobm", "[", 
   RowBox[{"i_", " ", ",", "h_", ",", 
    RowBox[{"k_:", "ind"}], ",", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", "\n", "\t", 
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"i", "<=", 
       RowBox[{"n", "-", "k"}]}], "&&", " ", 
      RowBox[{"h", ">", 
       RowBox[{"n", " ", "-", "k"}]}]}], ",", 
     RowBox[{
      RowBox[{"basismatrix", "[", 
       RowBox[{"i", ",", "h", ",", "n"}], "]"}], "+", 
      RowBox[{"basismatrix", "[", 
       RowBox[{"h", ",", "i", ",", "n"}], "]"}]}], ",", "\n", " ", 
     RowBox[{"obm", "[", " ", 
      RowBox[{"i", ",", " ", "h", ",", "n"}], "]"}]}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"i", "<", "h"}], " ", "&&", " ", 
     RowBox[{"k", " ", "<=", " ", "n"}]}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[30]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"psobasis", "[", 
   RowBox[{
    RowBox[{"k_:", "ind"}], ",", " ", 
    RowBox[{"n_:", "dim"}]}], "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"psobm", "[", 
         RowBox[{"i", ",", "j", ",", "k", ",", "n"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", 
          RowBox[{"i", "+", "1"}], ",", "n"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "n"}], "}"}]}], "]"}], ",", "1"}], "]"}]}]], "Input",\

 InitializationCell->True,
 CellLabel->"In[31]:="],

Cell["\<\
The abitrary element of the pseudo-orthogonal Lie algebra o(k, n):  \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psoelm", "[", 
   RowBox[{"a_", ",", 
    RowBox[{"k_:", "ind"}], ",", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"psobm", "[", 
         RowBox[{"i", ",", " ", "j", ",", "k", ",", "n"}], "]"}], " ", 
        RowBox[{"a", "[", 
         RowBox[{"i", ",", " ", "j"}], "]"}]}], ",", " ", "\n", "\t\t\t", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"j", " ", "-", "1"}]}], "}"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", "2", ",", " ", "n"}], "}"}]}], "]"}], " ", "/;", 
   
   RowBox[{"k", "<=", " ", "n"}]}]}]], "Input",
 PageWidth->Infinity,
 InitializationCell->True,
 ShowSpecialCharacters->False,
 CellLabel->"In[32]:="],

Cell[CellGroupData[{

Cell["Examples, tests", "Subsubsection"],

Cell[BoxData["dim"], "Input",
 CellChangeTimes->{{3.471761666922448*^9, 3.471761667475979*^9}},
 CellLabel->"In[91]:="],

Cell[BoxData["ind"], "Input",
 CellChangeTimes->{{3.471761679965471*^9, 3.471761680562205*^9}},
 CellLabel->"In[93]:="],

Cell[BoxData[
 RowBox[{"psobasis", "[", 
  RowBox[{"1", ",", "3"}], "]"}]], "Input",
 CellLabel->"In[92]:="],

Cell[BoxData[
 RowBox[{"psobasis", "[", "]"}]], "Input",
 CellLabel->"In[94]:="],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"MatrixForm", ",", "%"}], "]"}]], "Input",
 CellLabel->"In[95]:="],

Cell["\<\

psobm[1,2]//MatrixForm\
\>", "Input",
 PageWidth->Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[96]:="],

Cell["\<\

psobm[4,5]//MatrixForm\
\>", "Input",
 PageWidth->Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[97]:="],

Cell["\<\

psobm[1,4,2,4]//MatrixForm\
\>", "Input",
 PageWidth->Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[98]:="],

Cell["psoelm[a] //MatrixForm", "Input",
 PageWidth->Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[99]:="],

Cell["psoelm[a,2,6] //MatrixForm", "Input",
 PageWidth->Infinity,
 ShowSpecialCharacters->False,
 CellLabel->"In[100]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2 The Killing form of o(n,k)", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psokilling", "[", 
   RowBox[{"a_", ",", " ", "b_", ",", 
    RowBox[{"k_:", "ind"}], ",", " ", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"cobasis", "[", 
        RowBox[{"i", ",", " ", "j", ",", "n"}], "]"}], "[", " ", 
       RowBox[{"Evaluate", "[", 
        RowBox[{"commute", "[", 
         RowBox[{"a", ",", " ", 
          RowBox[{"commute", "[", 
           RowBox[{"b", ",", " ", 
            RowBox[{"psobm", "[", 
             RowBox[{"i", ",", "j", ",", "k", " ", ",", " ", "n"}], "]"}]}], 
           "]"}]}], "]"}], "]"}], "]"}], ",", " ", "\n", "    ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "1", ",", " ", 
        RowBox[{"j", " ", "-", " ", "1"}]}], "}"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"j", ",", " ", "2", ",", " ", "n"}], "}"}]}], "]"}], 
  " "}]], "Input",
 InitializationCell->True,
 CellLabel->"In[33]:="],

Cell["\<\
Using the tables [3] one concludes that the index of inertia of this Killing \
form is\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psoindex", "[", 
   RowBox[{"k_", ",", "n_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"k", "^", "2"}], " ", "-", 
   RowBox[{"k", "*", "n"}], " ", "+", " ", 
   RowBox[{"n", "*", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"n", "-", "1"}], ")"}], "/", "2"}]}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[34]:="],

Cell["\<\
Comparing this value with the index of the Killing forms calculated below \
controls our constructions.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"psoindex", "[", 
  RowBox[{"1", ",", "5"}], "]"}]], "Input",
 CellLabel->"In[101]:="],

Cell[BoxData[
 RowBox[{"psokilling", "[", 
  RowBox[{
   RowBox[{"psoelm", "[", "a", "]"}], ",", 
   RowBox[{"psoelm", "[", "a", "]"}]}], "]"}]], "Input",
 CellLabel->"In[102]:="],

Cell["\<\
Again the Killing form psokilling is conformal to the restriction of \
glkilling:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "/", 
   RowBox[{"glkilling", "[", 
    RowBox[{
     RowBox[{"psoelm", "[", "a", "]"}], ",", 
     RowBox[{"psoelm", "[", "a", "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47176191515765*^9, 3.471761928173472*^9}},
 CellLabel->"In[103]:="],

Cell[BoxData[
 RowBox[{"psoindex", "[", 
  RowBox[{"2", ",", "5"}], "]"}]], "Input",
 CellLabel->"In[104]:="],

Cell[BoxData[
 RowBox[{"psokilling", "[", 
  RowBox[{
   RowBox[{"psoelm", "[", 
    RowBox[{"a", ",", "2", ",", "5"}], "]"}], ",", 
   RowBox[{"psoelm", "[", 
    RowBox[{"a", ",", "2", ",", "5"}], "]"}], ",", "2", ",", "5"}], 
  "]"}]], "Input",
 CellLabel->"In[105]:="],

Cell["\<\
For n > 2 all the pseudo-orthogonal Lie algebras have a non-degenerate, and, \
for n > k > 0, indefinite Killing form; the standard Basis is orthogonal.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Timing: The Killing form of o(19, 1):                   ", \
"Subsubsection",
 PageWidth->Infinity,
 ShowSpecialCharacters->False],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"psokilling", "[", 
   RowBox[{
    RowBox[{"psoelm", "[", "a", "]"}], ",", 
    RowBox[{"psoelm", "[", "a", "]"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[106]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"psokilling", "[", 
   RowBox[{
    RowBox[{"psoelm", "[", 
     RowBox[{"a", ",", "1", ",", "19"}], "]"}], ",", 
    RowBox[{"psoelm", "[", 
     RowBox[{"a", ",", "1", ",", "19"}], "]"}], ",", "1", ",", "19"}], "]"}], 
  "]"}]], "Input",
 CellLabel->"In[107]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471762430792488*^9, 3.471762434267591*^9}},
 CellLabel->"In[108]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%%", "[", 
   RowBox[{"[", "2", "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.47176248154915*^9},
 CellLabel->"In[109]:="],

Cell[TextData[{
 "From the shape of this Killing form we conclude:\n1. The standard basis of \
o(19,1) is orthogonal.\n2. All its elements have the same absolute length ",
 Cell[BoxData[
  FormBox[
   SqrtBox["34"], TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "-", "1"}], ")"}], "/", "2"}]}], " ", "-", 
  RowBox[{"psoindex", "[", 
   RowBox[{"1", ",", "n"}], "]"}]}]], "Input",
 CellLabel->"In[110]:="],

Cell[TextData[{
 "Result: The index of the negative Killing form  -psokillingForm[a,b,1,n] \
equals n-1, what coincides with the result for n = 19.   \nFor the \
calculation for k=1 and n=19 the AT  486 needed 50 CPU minutes. The Dell \
Inspiron 3200 laptop needed 168s  only!  Strange is that we now, with the  \
Precision 370 and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 7.0,  needed 275 s."
}], "Text",
 CellChangeTimes->{{3.471763281202669*^9, 3.471763364056208*^9}}],

Cell["\<\
To get an orthonormal basis it suffices to normalize the elements of \
psobasis[1,19]: By the result above we may define:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"psnormbasis", " ", "=", " ", 
   RowBox[{
    RowBox[{"psobasis", "[", 
     RowBox[{"1", ",", "19"}], "]"}], "/", 
    RowBox[{"Sqrt", "[", "34", "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[111]:="],

Cell[BoxData[
 RowBox[{"psnormbasis", "[", 
  RowBox[{"[", "18", "]"}], "]"}]], "Input",
 CellLabel->"In[112]:="],

Cell[BoxData[
 RowBox[{"psokilling", "[", 
  RowBox[{
   RowBox[{"psnormbasis", "[", 
    RowBox[{"[", "18", "]"}], "]"}], ",", 
   RowBox[{"psnormbasis", "[", 
    RowBox[{"[", "18", "]"}], "]"}], ",", "1", ",", "19"}], "]"}]], "Input",
 CellLabel->"In[113]:="],

Cell["For testing the time we want to apply normalize, and define", "Text",
 CellChangeTimes->{3.471763432586594*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"psoprod", "[", 
    RowBox[{"k_", ",", "n_"}], "]"}], "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], ":=", " ", 
  RowBox[{"psokilling", "[", 
   RowBox[{"a", ",", "b", ",", "k", ",", "n"}], "]"}]}]], "Input",
 CellLabel->"In[114]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"psoprod", "[", 
   RowBox[{"1", ",", "19"}], "]"}], "[", 
  RowBox[{
   RowBox[{"psnormbasis", "[", 
    RowBox[{"[", "100", "]"}], "]"}], ",", 
   RowBox[{"psnormbasis", "[", 
    RowBox[{"[", "100", "]"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[115]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"normalize", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"psobasis", "[", 
        RowBox[{"1", ",", "19"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"psoprod", "[", 
       RowBox[{"1", ",", "19"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "171"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47176349433685*^9, 3.47176350142871*^9}},
 CellLabel->"In[121]:="],

Cell[TextData[{
 "Dell Inspiron  3200 needed 49 min to perform the 171 Normalizations of the \
19x19 matrices. Now, with the Dell Precision 370 and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 7.0,  we needed only 221 s:"
}], "Text",
 CellChangeTimes->{{3.471764174998528*^9, 3.471764280562788*^9}}],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471764240186921*^9, 3.471764244932292*^9}},
 CellLabel->"In[122]:="]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5 The symplectic Lie algebras sp(2m, K)", "Section"],

Cell["\<\
The Lie algebra sp(2m,K) is the Lie algebra of the symplectic group Sp(2m,K), \
which consists of all linear automorphisms of a 2m-dimensional vector space \
leaving a non degenerate alternating bilinear form invariant.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.1 The symplectic bilinear form", "Subsection"]], \
"Subsection"],

Cell["\<\
The symplectic bilinear form on a finite dimensional vector space is non \
degenerate and skew symmetric (alternating); it exists only for \
even-dimensional vector spaces. All such forms are equivalent under the \
action of the general linear group. Its matrix with respect to a standard \
basis is\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"alt", "[", 
   RowBox[{"n_", "?", "EvenQ"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"nullmatrix", "[", "n", "]"}]}], ",", " ", "i"}], "}"}], ",", 
    "\n", "\t\t", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", " ", "1"}], ",", " ", 
       RowBox[{"i", "<=", 
        RowBox[{"n", "/", "2"}]}], ",", " ", 
       RowBox[{"i", "++"}], ",", 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"m", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", 
             RowBox[{"i", " ", "+", " ", 
              RowBox[{"n", "/", "2"}]}]}], " ", "]"}], "]"}], " ", "=", " ", 
          "1"}], ";", " ", 
         RowBox[{
          RowBox[{"m", "[", 
           RowBox[{"[", 
            RowBox[{
             RowBox[{"i", "+", 
              RowBox[{"n", "/", "2"}]}], ",", " ", "i"}], "]"}], "]"}], "=", 
          " ", 
          RowBox[{"-", "1"}]}], ";"}], ")"}]}], "]"}], ";", "\n", "\t\t", 
     "m"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"alt", "[", "10", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[123]:="],

Cell[BoxData[
 RowBox[{"Det", "[", "%", "]"}]], "Input",
 CellLabel->"In[124]:="],

Cell["The symplectic bilinear form is", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"altprod", "[", 
   RowBox[{"x_List", ",", "y_List"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"x", ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"alt", "[", 
       RowBox[{"Length", "[", "x", "]"}], "]"}], ".", "y"}], ")"}]}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Length", "[", "x", "]"}], "==", 
      RowBox[{"Length", "[", "y", "]"}]}], "&&", 
     RowBox[{"EvenQ", "[", 
      RowBox[{"Length", "[", "x", "]"}], "]"}]}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[36]:="],

Cell["\<\
On a 2-dimensional vector space altprod coincides with the determinant:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"altprod", "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"x", ",", "2"}], "]"}], ",", " ", 
   RowBox[{"vec", "[", 
    RowBox[{"y", ",", "2"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[125]:="],

Cell[BoxData[
 RowBox[{"altprod", "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"x", ",", "6"}], "]"}], ",", " ", 
   RowBox[{"vec", "[", 
    RowBox[{"y", ",", "6"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[126]:="],

Cell[BoxData[
 RowBox[{"altprod", "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"x", ",", "4"}], "]"}], ",", " ", 
   RowBox[{"vec", "[", 
    RowBox[{"y", ",", "2"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[127]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"altprod", "[", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"x", ",", "4"}], "]"}], ",", " ", 
    RowBox[{"vec", "[", 
     RowBox[{"y", ",", "4"}], "]"}]}], "]"}], " ", "+", " ", 
  RowBox[{"altprod", "[", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"y", ",", "4"}], "]"}], ",", " ", 
    RowBox[{"vec", "[", 
     RowBox[{"x", ",", "4"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[128]:="],

Cell[BoxData[
 RowBox[{"altprod", "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"x", ",", "4"}], "]"}], ",", " ", 
   RowBox[{"vec", "[", 
    RowBox[{"x", ",", "4"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[129]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2 Basis and general element", "Subsection"],

Cell["\<\
The set of the elements defined as follows contains a basis of the Lie \
algebra sp(2n,K); for simplicity we admit that some of the elements \
spbasis[i,j,n] are nullmatrices.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spbasis", "[", 
   RowBox[{"i_", ",", " ", "j_", ",", " ", 
    RowBox[{"n_", "?", "EvenQ"}]}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"nullmatrix", "[", "n", "]"}]}], ",", " ", 
      RowBox[{"k", " ", "=", " ", 
       RowBox[{"n", "/", "2"}]}]}], "}"}], ",", "\n", "\t\t", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"i", "<=", "k"}], "&&", 
        RowBox[{"j", "<=", "k"}]}], ",", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"m", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", "=", " ", "1"}], ";", 
        " ", 
        RowBox[{
         RowBox[{"m", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"k", "+", "j"}], ",", " ", 
            RowBox[{"k", "+", "i"}]}], "]"}], "]"}], " ", "=", " ", 
         RowBox[{"-", "1"}]}], ";", 
        RowBox[{"Return", "[", "m", "]"}]}]}], "]"}], ";", "\n", "\t\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"i", "<=", "k"}], "&&", 
        RowBox[{"i", "<=", 
         RowBox[{"j", "-", "k"}], " ", "<=", "k"}]}], ",", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"m", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", "=", " ", "1"}], ";", 
        " ", 
        RowBox[{
         RowBox[{"m", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"j", "-", "k"}], ",", 
            RowBox[{"i", " ", "+", " ", "k"}]}], "]"}], "]"}], " ", "=", " ", 
         "1"}], ";", " ", 
        RowBox[{"Return", "[", "m", "]"}]}]}], "]"}], ";", "\n", "\t\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"i", " ", ">", " ", "k"}], "&&", " ", 
        RowBox[{
         RowBox[{"i", "-", "k"}], "<=", "j", " ", "<=", " ", "k"}]}], ",", 
       " ", 
       RowBox[{
        RowBox[{
         RowBox[{"m", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", "=", " ", "1"}], ";", 
        " ", 
        RowBox[{
         RowBox[{"m", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"k", "+", "j"}], ",", 
            RowBox[{"i", "-", "k"}]}], "]"}], "]"}], "=", " ", "1"}], ";", 
        RowBox[{"Return", "[", "m", "]"}]}]}], "]"}], ";", "\n", "\t\t", 
     RowBox[{"Return", "[", 
      RowBox[{"nullmatrix", "[", "n", "]"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[37]:="],

Cell["\<\
Applying matrixoutzero we may construct a basis of sp(2n, K):\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"basislist", "[", 
   RowBox[{"n_", "?", "EvenQ"}], "]"}], " ", ":=", "  ", 
  RowBox[{"matrixoutzero", "[", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"spbasis", "[", 
        RowBox[{"i", ",", "j", ",", "n"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "n"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "n"}], "}"}]}], "]"}], ",", "1"}], "]"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[38]:="],

Cell["\<\
Since the nullmatrices do not contribute to the sum, the general element of \
sp[2n, K) can be defined as\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spelm", "[", 
   RowBox[{"a_", ",", 
    RowBox[{"n_", "?", "EvenQ"}]}], "]"}], " ", ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"spbasis", "[", 
      RowBox[{"i", ",", "j", ",", "n"}], "]"}], "*", 
     RowBox[{"a", "[", 
      RowBox[{"i", ",", "j"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "n"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "n"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[39]:="],

Cell[CellGroupData[{

Cell["Examples, tests", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spbasis", "[", 
   RowBox[{"1", ",", "1", ",", "2"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[130]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"spbasis", "[", 
    RowBox[{"i", ",", "j", ",", "2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[131]:="],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"MatrixForm", ",", 
   RowBox[{"basislist", "[", "2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.471765064108623*^9, 3.471765087639388*^9}},
 CellLabel->"In[132]:="],

Cell[BoxData[
 RowBox[{"spbasis", "[", 
  RowBox[{"2", ",", "1", ",", "2"}], "]"}]], "Input",
 CellLabel->"In[133]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"spbasis", "[", 
     RowBox[{"i", ",", "j", ",", "4"}], "]"}], "//", "MatrixForm"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[134]:="],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"MatrixForm", ",", 
   RowBox[{"basislist", "[", "4", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.471765189964513*^9, 3.471765211154076*^9}},
 CellLabel->"In[135]:="],

Cell["Evaluating the next cell we learn that sp(2, K) =  sl(2, K):", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spelm", "[", 
   RowBox[{"a", ",", "2"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[136]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"spelm", "[", 
   RowBox[{"a", ",", "4"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.471765295826385*^9, 3.471765300948723*^9}},
 CellLabel->"In[138]:="],

Cell["Here is a test of the invariance condition:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Transpose", "[", "%", "]"}], ".", 
   RowBox[{"alt", "[", "4", "]"}]}], " ", "+", " ", 
  RowBox[{
   RowBox[{"alt", "[", "4", "]"}], ".", "%"}]}]], "Input",
 CellLabel->"In[139]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"basislist", "[", "10", "]"}], ";"}]], "Input",
 CellLabel->"In[141]:="],

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellLabel->"In[142]:="],

Cell[BoxData[
 RowBox[{"sptt4", " ", "=", " ", 
  RowBox[{"basislist", "[", "4", "]"}]}]], "Input",
 CellLabel->"In[143]:="],

Cell[BoxData[
 RowBox[{"Length", "[", "sptt4", "]"}]], "Input",
 CellLabel->"In[144]:="],

Cell["Test of the invariance condition:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spelm", "[", 
   RowBox[{"a", ",", "6"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[145]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"%", ".", 
   RowBox[{"alt", "[", "6", "]"}]}], " ", "+", 
  RowBox[{
   RowBox[{"alt", "[", "6", "]"}], ".", 
   RowBox[{"Transpose", "[", "%", "]"}]}]}]], "Input",
 CellLabel->"In[146]:="],

Cell["\<\
The dimension of the Lie algebra sp(2m, K) is (with n = 2m), see [3], p.32:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spdim", "[", 
   RowBox[{"n_", "?", "EvenQ"}], "]"}], " ", ":=", " ", 
  RowBox[{"n", "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"n", "+", "1"}], ")"}], "/", "2"}]}]}]], "Input",
 CellLabel->"In[147]:="],

Cell[BoxData[
 RowBox[{"spdim", "[", "2", "]"}]], "Input",
 CellLabel->"In[148]:="],

Cell[BoxData[
 RowBox[{"spdim", "[", "4", "]"}]], "Input",
 CellLabel->"In[149]:="],

Cell[BoxData[
 RowBox[{"spdim", "[", "10", "]"}]], "Input",
 CellLabel->"In[150]:="],

Cell["This coincides with the lengths of our basislists.", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2 The Killingform spkilling", "Subsection"],

Cell["\<\
Since nullmatrices do not contribute terms to the Killing form we may define\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spkilling", "[", 
   RowBox[{"a_", ",", " ", "b_", ",", 
    RowBox[{"n_", "?", "EvenQ"}]}], "]"}], " ", ":=", "\n", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"cobasis", "[", 
        RowBox[{"i", ",", " ", "j", ",", "n"}], "]"}], "[", " ", 
       RowBox[{"commute", "[", 
        RowBox[{"a", ",", " ", 
         RowBox[{"commute", "[", 
          RowBox[{"b", ",", 
           RowBox[{"spbasis", "[", 
            RowBox[{"i", ",", " ", "j", ",", "n"}], "]"}]}], "]"}]}], "]"}], 
       "]"}], ",", "\n", "        ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "1", ",", " ", "n"}], "}"}]}], "]"}], ",", " ", 
    
    RowBox[{"{", 
     RowBox[{"j", ",", " ", "1", ",", " ", "n"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.47176551121086*^9, 3.471765516998659*^9}},
 CellLabel->"In[40]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"spkilling", "[", 
   RowBox[{
    RowBox[{"spelm", "[", 
     RowBox[{"a", ",", "2"}], "]"}], ",", " ", 
    RowBox[{"spelm", "[", 
     RowBox[{"b", ",", "2"}], "]"}], ",", " ", "2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471765582633742*^9, 3.471765590931684*^9}},
 CellLabel->"In[153]:="],

Cell["Of course, this coincides with the Killing form of sl(2,K):", "Text"],

Cell[BoxData[
 RowBox[{"glkilling", "[", 
  RowBox[{
   RowBox[{"spelm", "[", 
    RowBox[{"a", ",", "2"}], "]"}], ",", " ", 
   RowBox[{"spelm", "[", 
    RowBox[{"b", ",", "2"}], "]"}], ",", " ", "2"}], "]"}]], "Input",
 CellLabel->"In[152]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"spkilling", "[", 
   RowBox[{
    RowBox[{"spelm", "[", 
     RowBox[{"a", ",", "6"}], "]"}], ",", " ", 
    RowBox[{"spelm", "[", 
     RowBox[{"a", ",", "6"}], "]"}], ",", " ", "6"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471765723034576*^9, 3.471765730422767*^9}},
 CellLabel->"In[160]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"glkilling", "[", 
   RowBox[{
    RowBox[{"spelm", "[", 
     RowBox[{"a", ",", "6"}], "]"}], ",", " ", 
    RowBox[{"spelm", "[", 
     RowBox[{"a", ",", "6"}], "]"}], ",", " ", "6"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471765746473883*^9, 3.47176575463513*^9}},
 CellLabel->"In[161]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "/", "%%"}], "]"}]], "Input",
 CellChangeTimes->{{3.47176565313189*^9, 3.471765664089608*^9}},
 CellLabel->"In[162]:="],

Cell["\<\
Again we obtained the conformality to the restriction of the Killing form of \
the general linear Lie algebra.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"spdim", "[", "6", "]"}]], "Input",
 CellLabel->"In[163]:="],

Cell[BoxData[
 RowBox[{"spdim", "[", "12", "]"}]], "Input",
 CellLabel->"In[164]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"spkilling", "[", 
   RowBox[{
    RowBox[{"spelm", "[", 
     RowBox[{"a", ",", "12"}], "]"}], ",", " ", 
    RowBox[{"spelm", "[", 
     RowBox[{"a", ",", "12"}], "]"}], ",", " ", "12"}], "]"}], "]"}]], "Input",\

 CellLabel->"In[165]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[166]:="],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " needed 30.15 s."
}], "Text"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%%", "[", 
   RowBox[{"[", "2", "]"}], "]"}], "]"}]], "Input",
 CellLabel->"In[167]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"spprod", "[", 
    RowBox[{"n_", "?", "EvenQ"}], "]"}], "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], " ", ":=", " ", 
  RowBox[{"spkilling", "[", 
   RowBox[{"a", ",", "b", ",", "n"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[41]:="],

Cell[BoxData[
 RowBox[{"matrixorthonorm", "[", 
  RowBox[{
   RowBox[{"basislist", "[", "2", "]"}], ",", 
   RowBox[{"innerprod", " ", "\[Rule]", " ", 
    RowBox[{"spprod", "[", "2", "]"}]}]}], "]"}]], "Input",
 CellLabel->"In[169]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"spprod", "[", "2", "]"}], "[", 
    RowBox[{
     RowBox[{"%", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"%", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[170]:="],

Cell[BoxData[
 RowBox[{"matrixorthonorm", "[", 
  RowBox[{
   RowBox[{"basislist", "[", "4", "]"}], ",", 
   RowBox[{"innerprod", " ", "\[Rule]", " ", 
    RowBox[{"spprod", "[", "4", "]"}]}]}], "]"}]], "Input",
 CellLabel->"In[171]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sptest", "[", "4", "]"}], " ", "=", "%"}], ";"}]], "Input",
 CellLabel->"In[172]:="],

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"sptest", "[", "4", "]"}], "]"}]], "Input",
 CellLabel->"In[173]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"spprod", "[", "4", "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"sptest", "[", "4", "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"sptest", "[", "4", "]"}], "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "10"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",\

 CellLabel->"In[174]:="],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " needed 222 s  for the next calculation, on the Dell Inspiron 3200 under \
Linux, now, on the Dell Precision 370, 20 s. only:"
}], "Text",
 CellChangeTimes->{{3.471766032950591*^9, 3.47176605836288*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"matrixorthonorm", "[", 
   RowBox[{
    RowBox[{"basislist", "[", "6", "]"}], ",", 
    RowBox[{"innerprod", "  ", "\[Rule]", " ", 
     RowBox[{"spprod", "[", "6", "]"}]}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[175]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[176]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sptest", "[", "6", "]"}], " ", "=", 
   RowBox[{"%%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[177]:="],

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"sptest", "[", "6", "]"}], "]"}]], "Input",
 CellLabel->"In[178]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"sptest", "[", "6", "]"}], "[", 
     RowBox[{"[", "i", "]"}], "]"}], "//", "MatrixForm"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "21"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[179]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"spprod", "[", "6", "]"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"sptest", "[", "6", "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"sptest", "[", "6", "]"}], "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "21"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "21"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",\

 CellLabel->"In[180]:="],

Cell["\<\
From the tables [3], p. 33,   it follows that the index of the Killlingform \
spkilling[a,b,n], n even, is\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spindex", "[", 
   RowBox[{"n_", "?", "EvenQ"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"n", "^", "2"}], "/", "4"}]}]], "Input",
 CellLabel->"In[181]:="],

Cell["and this coincides with our results:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", "k"}], ",", " ", 
      RowBox[{"spindex", "[", 
       RowBox[{"2", "k"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"k", ",", "3"}], "}"}]}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{3.471766292310527*^9},
 CellLabel->"In[183]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
6 The unitary and the special unitary Lie algebras u(n), su(n)\
\>", "Section"],

Cell[TextData[{
 StyleBox["Attention:",
  FontColor->RGBColor[1, 0, 0]],
 " Not all the needed cells of this section are initialized, since  first  \
the package [4] must be downloaded from ",
 StyleBox["MathSource",
  FontSlant->"Italic"],
 " (see below). Only if this is done, the section may be evaluated completely!"
}], "Text",
 CellChangeTimes->{{3.471766347219218*^9, 3.471766350347927*^9}}],

Cell[CellGroupData[{

Cell["6.1 A basis of u(n)", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ubasisa", "[", 
   RowBox[{"i_", ",", " ", "j_", ",", " ", 
    RowBox[{"n_:", "dim"}]}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"obm", "[", 
    RowBox[{"i", ",", "j", ",", "n"}], "]"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"i", "<", " ", "j"}], " ", "&&", " ", 
     RowBox[{"j", "<=", " ", "n"}]}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[42]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ubasisb", "[", 
   RowBox[{"i_", ",", " ", "j_", ",", " ", 
    RowBox[{"n_:", "dim"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"basismatrix", "[", 
       RowBox[{"i", ",", "j", ",", "n"}], "]"}], "+", " ", 
      RowBox[{"basismatrix", "[", 
       RowBox[{"j", ",", "i", ",", "n"}], "]"}]}], ")"}], "*", "I"}], "/;", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"i", "<", " ", "j"}], " ", "&&", " ", 
     RowBox[{"j", "<=", " ", "n"}]}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[43]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ubasisc", "[", 
   RowBox[{"i_", ",", "  ", 
    RowBox[{"n_:", "dim"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"basismatrix", "[", 
     RowBox[{"i", ",", "i", ",", "n"}], "]"}], "*", "I"}], "/;", 
   RowBox[{"(", 
    RowBox[{"i", "<=", " ", "n"}], ")"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[44]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ubasis", "[", 
   RowBox[{"n_:", "dim"}], "]"}], " ", ":=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"ubasisa", "[", 
           RowBox[{"i", ",", "j", ",", "n"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", " ", "2", ",", "n"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"j", "-", "1"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"ubasisb", "[", 
           RowBox[{"i", ",", "j", ",", "n"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", " ", "2", ",", "n"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"j", "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", " ", 
      "1"}], "]"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ubasisc", "[", 
       RowBox[{"i", ",", "n"}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[45]:="],

Cell[CellGroupData[{

Cell["Tests", "Subsubsection"],

Cell[TextData[{
 "The dimension of the real vector space u(n) is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "2"], TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"ubasis", "[", "10", "]"}], "]"}]], "Input",
 CellLabel->"In[184]:="],

Cell[BoxData[
 RowBox[{"ubasis", "[", "3", "]"}]], "Input",
 CellLabel->"In[185]:="],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"MatrixForm", ",", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.471766442407807*^9, 3.471766468350282*^9}},
 CellLabel->"In[186]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.2 Declare real coefficients", "Subsection"],

Cell["\<\
In spite of the fact that u(n) consists of complex matrices it is a real Lie \
algebra: a complex square matrix of order n belongs to u(n) if and only if it \
fulfils\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Transpose", "[", 
   RowBox[{"matrix", "[", "a", "]"}], "]"}], " ", "==", " ", 
  RowBox[{"-", 
   RowBox[{"Conjugate", "[", 
    RowBox[{"matrix", "[", "a", "]"}], "]"}]}]}]], "Input",
 CellLabel->"In[187]:="],

Cell["\<\
This condition is preserved under linear combination with real coefficients \
only.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", "=", " ", 
   RowBox[{
    RowBox[{"ubasis", "[", "3", "]"}], "[", 
    RowBox[{"[", "9", "]"}], "]"}]}], ";", 
  RowBox[{
   RowBox[{"Transpose", "[", "a", "]"}], "==", " ", 
   RowBox[{"-", 
    RowBox[{"Conjugate", "[", "a", "]"}]}]}]}]], "Input",
 CellLabel->"In[188]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"ubasis", "[", "3", "]"}], "[", 
     RowBox[{"[", "9", "]"}], "]"}], "*", "I"}]}], ";", 
  RowBox[{
   RowBox[{"Transpose", "[", "a", "]"}], "==", " ", 
   RowBox[{"-", 
    RowBox[{"Conjugate", "[", "a", "]"}]}]}]}]], "Input",
 CellLabel->"In[189]:="],

Cell[BoxData[
 RowBox[{"Remove", "[", "a", "]"}]], "Input",
 CellLabel->"In[190]:="],

Cell[TextData[{
 "Thus we have to declare that the coordinates of the elements of u(n) shall \
be real. This can be done by the function Declare contained in the package \
[",
 ButtonBox["4",
  BaseStyle->"Hyperlink",
  ButtonData->"ref"],
 "] by Pekka Janhunen. First download the package, and copy it in the working \
directory "
}], "Text",
 CellChangeTimes->{{3.471766591987717*^9, 3.471766591989063*^9}, {
  3.471766735119664*^9, 3.471766750750679*^9}}],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<~/mymath/Lie\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.471766629675008*^9, 3.471766638443627*^9}, {
  3.471766677120177*^9, 3.471766702120489*^9}},
 CellLabel->"In[46]:="],

Cell["Then import", "Text",
 CellChangeTimes->{3.471766759573848*^9}],

Cell[BoxData[
 RowBox[{"<<", "Declare.m"}]], "Input",
 CellLabel->"In[47]:="],

Cell["We add some rules for the function Conjugate:", "Text"],

Cell[BoxData[
 RowBox[{"Unprotect", "[", "Conjugate", "]"}]], "Input",
 CellLabel->"In[48]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conjugate", "[", 
   RowBox[{
    RowBox[{"x_", "?", "RealQ"}], " ", "+", 
    RowBox[{"I", "*", 
     RowBox[{"y_", "?", "RealQ"}]}]}], "]"}], ":=", 
  RowBox[{"x", " ", "-", " ", 
   RowBox[{"I", "*", "y"}]}]}]], "Input",
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conjugate", "[", 
   RowBox[{"x_", "?", "RealQ"}], "]"}], " ", ":=", " ", "x"}]], "Input",
 CellLabel->"In[50]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conjugate", "[", 
   RowBox[{"I", "*", 
    RowBox[{"x_", "?", "RealQ"}]}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"-", "I"}], "*", "x"}]}]], "Input",
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{"Protect", "[", "Conjugate", "]"}]], "Input",
 CellLabel->"In[52]:="],

Cell["\<\
Now evaluate the definitions contained in the next subsection.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"?", "Declare"}]], "Input",
 CellLabel->"In[53]:="],

Cell[BoxData[
 RowBox[{"?", "NewDeclare"}]], "Input",
 CellChangeTimes->{{3.471766837604731*^9, 3.471766842161279*^9}},
 CellLabel->"In[54]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3 General element, cobasis, and Killing form of u(n)", "Subsection"],

Cell[CellGroupData[{

Cell["Definitions", "Subsubsection"],

Cell[TextData[{
 StyleBox["Now evaluate the subsubsection",
  FontColor->RGBColor[1, 0, 0]],
 " \"",
 StyleBox["Definitions",
  FontColor->RGBColor[0, 0, 1]],
 "\"!\nThe general element of the Lie algebra u(n) is"
}], "Text",
 CellChangeTimes->{{3.471766933526757*^9, 3.47176698899312*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "dim", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.471766900209434*^9, 3.471766907893585*^9}},
 CellLabel->"In[55]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"uelm", "[", 
   RowBox[{"a_", ",", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", " ", 
      RowBox[{"c", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"a", "[", "k", "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"k", ",", "  ", 
           RowBox[{"n", "^", "2"}]}], "}"}]}], "]"}]}]}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"Declare", "[", 
      RowBox[{"c", ",", "Real"}], "]"}], ";", "\n", "\t\t\t ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ubasis", "[", "n", "]"}], "[", 
         RowBox[{"[", "k", "]"}], "]"}], "*", 
        RowBox[{"a", "[", "k", "]"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", " ", 
         RowBox[{"n", "^", "2"}]}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[56]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ucobasisa", "[", 
    RowBox[{"i_", ",", "j_", ",", 
     RowBox[{"n_:", "dim"}]}], "]"}], "[", 
   RowBox[{"m_", "?", "MatrixQ"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Re", "[", 
    RowBox[{
     RowBox[{"cobasis", "[", 
      RowBox[{"i", ",", "j", ",", "n"}], "]"}], "[", "m", "]"}], "]"}], "/;", 
   
   RowBox[{"(", 
    RowBox[{
     RowBox[{"i", "<", "j"}], "&&", 
     RowBox[{"j", "<=", "n"}]}], ")"}]}]}]], "Input",
 CellLabel->"In[57]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ucobasisb", "[", 
    RowBox[{"i_", ",", "j_", ",", 
     RowBox[{"n_:", "dim"}]}], "]"}], "[", 
   RowBox[{"m_", "?", "MatrixQ"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{
     RowBox[{"cobasis", "[", 
      RowBox[{"i", ",", "j", ",", "n"}], "]"}], "[", "m", "]"}], "]"}], "/;", 
   
   RowBox[{"(", 
    RowBox[{
     RowBox[{"i", "<", "j"}], "&&", 
     RowBox[{"j", "<=", "n"}]}], ")"}]}]}]], "Input",
 CellLabel->"In[58]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ucobasisc", "[", 
    RowBox[{"i_", ",", 
     RowBox[{"n_:", "dim"}]}], "]"}], "[", 
   RowBox[{"m_", "?", "MatrixQ"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"Im", "[", 
    RowBox[{
     RowBox[{"cobasis", "[", 
      RowBox[{"i", ",", "i", ",", "n"}], "]"}], "[", "m", "]"}], "]"}], "/;", 
   
   RowBox[{"(", 
    RowBox[{"i", "<=", "n"}], ")"}]}]}]], "Input",
 CellLabel->"In[59]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ucobasis", "[", 
    RowBox[{"n_:", "dim"}], "]"}], "[", 
   RowBox[{"m_", "?", "MatrixQ"}], "]"}], " ", ":=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ucobasisa", "[", 
            RowBox[{"i", ",", "j", ",", "n"}], "]"}], "[", "m", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", " ", "2", ",", "n"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"j", "-", "1"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ucobasisb", "[", 
            RowBox[{"i", ",", "j", ",", "n"}], "]"}], "[", "m", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", " ", "2", ",", "n"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"j", "-", "1"}]}], "}"}]}], "]"}]}], "]"}], ",", " ", 
      "1"}], "]"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ucobasisc", "[", 
        RowBox[{"i", ",", "n"}], "]"}], "[", "m", "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[60]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ukilling", "[", 
   RowBox[{
    RowBox[{"x_", "?", "MatrixQ"}], ",", " ", 
    RowBox[{"y_", "?", "MatrixQ"}], ",", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"ucobasis", "[", "n", "]"}], "[", 
      RowBox[{"commute", "[", 
       RowBox[{"x", ",", 
        RowBox[{"commute", "[", 
         RowBox[{"y", ",", 
          RowBox[{
           RowBox[{"ubasis", "[", "n", "]"}], "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "]"}], "]"}], "[", 
     RowBox[{"[", "i", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", 
      RowBox[{"n", "^", "2"}]}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[61]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples, Tests", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"uelm", "[", 
   RowBox[{"a", ",", "2"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[208]:="],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   RowBox[{"Conjugate", "[", 
    RowBox[{"uelm", "[", 
     RowBox[{"ab", ",", "2"}], "]"}], "]"}], "==", 
   RowBox[{"-", 
    RowBox[{"Transpose", "[", 
     RowBox[{"uelm", "[", 
      RowBox[{"ab", ",", "2"}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellLabel->"In[209]:="],

Cell[BoxData[
 RowBox[{"RealQ", "[", 
  RowBox[{"a", "[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[210]:="],

Cell[BoxData[
 RowBox[{"Conjugate", "[", 
  RowBox[{"I", "*", 
   RowBox[{"a", "[", "3", "]"}]}], "]"}]], "Input",
 CellLabel->"In[211]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"uelm", "[", 
   RowBox[{"a", ",", "4"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[212]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conjugate", "[", 
   RowBox[{"uelm", "[", 
    RowBox[{"a", ",", "4"}], "]"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[215]:="],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   RowBox[{"Conjugate", "[", 
    RowBox[{"uelm", "[", 
     RowBox[{"a", ",", "4"}], "]"}], "]"}], "==", 
   RowBox[{"-", 
    RowBox[{"Transpose", "[", 
     RowBox[{"uelm", "[", 
      RowBox[{"a", ",", "4"}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellLabel->"In[216]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ucobasis", "[", "4", "]"}], "[", 
  RowBox[{"uelm", "[", 
   RowBox[{"a", ",", "4"}], "]"}], "]"}]], "Input",
 CellLabel->"In[217]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ucobasis", "[", "4", "]"}], "[", 
   RowBox[{"ubasisc", "[", 
    RowBox[{"1", ",", "4"}], "]"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471767323417992*^9, 3.471767330380473*^9}},
 CellLabel->"In[218]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ucobasis", "[", "4", "]"}], "[", 
   RowBox[{"ubasisc", "[", 
    RowBox[{"4", ",", "4"}], "]"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[219]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ucobasis", "[", "4", "]"}], "[", 
  RowBox[{"ubasisc", "[", 
   RowBox[{"4", ",", "4"}], "]"}], "]"}]], "Input",
 CellLabel->"In[220]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ucobasisc", "[", 
   RowBox[{"1", ",", "4"}], "]"}], "[", 
  RowBox[{"uelm", "[", 
   RowBox[{"a", ",", "4"}], "]"}], "]"}]], "Input",
 CellLabel->"In[221]:="],

Cell[BoxData[
 RowBox[{"ukilling", "[", 
  RowBox[{
   RowBox[{"uelm", "[", 
    RowBox[{"a", ",", "2"}], "]"}], ",", 
   RowBox[{"uelm", "[", 
    RowBox[{"a", ",", "2"}], "]"}], ",", "2"}], "]"}]], "Input",
 CellLabel->"In[222]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellLabel->"In[223]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"ukilling", "[", 
   RowBox[{
    RowBox[{"uelm", "[", 
     RowBox[{"a", ",", "4"}], "]"}], ",", 
    RowBox[{"uelm", "[", 
     RowBox[{"b", ",", "4"}], "]"}], ",", "4"}], "]"}], "]"}]], "Input",
 CellLabel->"In[224]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"glkilling", "[", 
   RowBox[{
    RowBox[{"uelm", "[", 
     RowBox[{"a", ",", "4"}], "]"}], ",", 
    RowBox[{"uelm", "[", 
     RowBox[{"b", ",", "4"}], "]"}], ",", "4"}], "]"}], "]"}]], "Input",
 CellLabel->"In[225]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "\[Equal]", "%%"}], "]"}]], "Input",
 CellChangeTimes->{{3.47176742490488*^9, 3.471767436751649*^9}},
 CellLabel->"In[226]:="],

Cell["\<\
In this case the unitary Killing form is just the restriction of the \
(complex) Killingform of the general linear Lie algebra!\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"uprod", "[", 
   RowBox[{"x_", ",", " ", "y_"}], "]"}], " ", ":=", " ", 
  RowBox[{"ukilling", "[", 
   RowBox[{"x", ",", "y", ",", "3"}], "]"}]}]], "Input",
 CellLabel->"In[227]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"uprod", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ubasis", "[", "3", "]"}], "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"ubasis", "[", "3", "]"}], "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "9"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[228]:="],

Cell[BoxData[
 RowBox[{"%", "//", "MatrixForm"}]], "Input",
 CellLabel->"In[229]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"matrixorthonorm", "[", 
   RowBox[{
    RowBox[{"ubasis", "[", "3", "]"}], ",", 
    RowBox[{"innerprod", "->", " ", "uprod"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[230]:="],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " needed 3.1 s  for this calculation."
}], "Text",
 CellChangeTimes->{{3.471767496619426*^9, 3.471767501530854*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"olist", " ", "=", " ", 
   RowBox[{"%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[231]:="],

Cell[BoxData[
 RowBox[{"Length", "[", "olist", "]"}]], "Input",
 CellLabel->"In[232]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"uprod", "[", 
     RowBox[{
      RowBox[{"olist", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"olist", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "9"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "9"}], "}"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[233]:="],

Cell[TextData[{
 "For this calculation ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " needed 17.11 s, now, with Dell Precision 370, 1.8 s only."
}], "Text",
 CellChangeTimes->{{3.471767547549712*^9, 3.471767580682042*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[234]:="],

Cell[BoxData[
 RowBox[{"dim", "=", "5"}]], "Input",
 CellChangeTimes->{{3.471767665762425*^9, 3.47176767853431*^9}},
 CellLabel->"In[237]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"ukilling", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"ubasis", "[", "]"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"ubasis", "[", "]"}], "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "25"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"j", ",", "25"}], "}"}]}], "]"}], "]"}], "//", "MatrixForm"}], 
  "]"}]], "Input",
 CellLabel->"In[238]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471767941537901*^9, 3.471767946002277*^9}},
 CellLabel->"In[239]:="],

Cell[TextData[{
 "For the last calculation ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " needed 33 min, with Dell Precision 370 only 160 s.."
}], "Text",
 CellChangeTimes->{{3.471767907383448*^9, 3.47176793154717*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"uprod4", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], " ", ":=", " ", 
  RowBox[{"ukilling", "[", 
   RowBox[{"a", ",", "b", ",", "4"}], "]"}]}]], "Input",
 CellLabel->"In[62]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"matrixorthonorm", "[", 
   RowBox[{
    RowBox[{"ubasis", "[", "4", "]"}], ",", " ", 
    RowBox[{"innerprod", " ", "\[Rule]", " ", "uprod4"}]}], "]"}], 
  "]"}]], "Input",
 CellLabel->"In[63]:="],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " needed 6.3 min for this orthonormalization. New time with Dell Precision \
370:  33 s"
}], "Text",
 CellChangeTimes->{{3.471770177785527*^9, 3.471770214240281*^9}}],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{3.471770172220494*^9},
 CellLabel->"In[64]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"olist4", " ", "=", " ", 
   RowBox[{"%%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[65]:="],

Cell[BoxData[
 RowBox[{"Length", "[", "olist4", "]"}]], "Input",
 CellLabel->"In[66]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"uprod4", "[", 
     RowBox[{
      RowBox[{"olist4", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
      RowBox[{"olist4", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "16"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"j", ",", "16"}], "}"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[67]:="],

Cell["Time: 228.38 s New time: 20.2013s", "Text",
 CellChangeTimes->{{3.471770288360569*^9, 3.471770302167842*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"%", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.471770321564725*^9, 3.471770329419372*^9}},
 CellLabel->"In[68]:="],

Cell[BoxData[
 RowBox[{"dim", " ", "=", " ", "5"}]], "Input",
 CellChangeTimes->{{3.471770354561702*^9, 3.471770357306063*^9}},
 CellLabel->"In[70]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"matrixorthonorm", "[", 
   RowBox[{
    RowBox[{"ubasis", "[", "]"}], ",", " ", 
    RowBox[{"innerprod", " ", "\[Rule]", " ", "ukilling"}]}], "]"}], 
  "]"}]], "Input",
 CellLabel->"In[71]:="],

Cell["The time needed was 51.2 min. New time: 245.5 s.", "Text",
 CellChangeTimes->{{3.471770659373862*^9, 3.471770677822303*^9}}],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.471770643897578*^9, 3.471770649015711*^9}},
 CellLabel->"In[72]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"u5list", " ", "=", " ", 
   RowBox[{"%%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[73]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"ukilling", "[", 
    RowBox[{
     RowBox[{"u5list", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"u5list", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", " ", "25"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"j", ",", " ", "25"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[74]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ubasis", "[", "]"}], "[", 
     RowBox[{"[", "i", "]"}], "]"}], "//", "MatrixForm"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"i", ",", "25"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[76]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.4 The special unitary Lie algebras su(n)", "Subsection"],

Cell["\<\
The special unitary Lie algebra su(n) is the subalgebra of the elements of \
u(n) with trace zero;as kernel of the trace map it is an ideal. Therefore its \
Killing form is the restriction of ukilling to su(n). We define a basis of \
su(n):  \
\>", "Text"],

Cell[BoxData[
 RowBox[{"Clear", "[", "dim", "]"}]], "Input",
 CellChangeTimes->{{3.471770987883357*^9, 3.471770997433242*^9}},
 CellLabel->"In[77]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subasis", "[", 
   RowBox[{"n_:", "dim"}], "]"}], " ", ":=", " ", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ubasis", "[", "n", "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", 
        RowBox[{"n", "*", 
         RowBox[{"(", 
          RowBox[{"n", "-", "1"}], ")"}]}]}], "}"}]}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"ubasis", "[", "n", "]"}], "[", 
        RowBox[{"[", "j", "]"}], "]"}], " ", "-", " ", 
       RowBox[{
        RowBox[{"ubasis", "[", "n", "]"}], "[", 
        RowBox[{"[", 
         RowBox[{"n", "^", "2"}], "]"}], "]"}]}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"j", ",", 
        RowBox[{
         RowBox[{"n", "*", 
          RowBox[{"(", 
           RowBox[{"n", "-", "1"}], ")"}]}], "+", "1"}], ",", " ", 
        RowBox[{
         RowBox[{"n", "^", "2"}], " ", "-", "1"}]}], "}"}]}], "]"}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[78]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"subasis", "[", "5", "]"}], "[", 
     RowBox[{"[", "j", "]"}], "]"}], "//", "MatrixForm"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"j", ",", 
     RowBox[{
      RowBox[{"5", "*", 
       RowBox[{"(", 
        RowBox[{"5", "-", "1"}], ")"}]}], "+", "1"}], ",", " ", 
     RowBox[{
      RowBox[{"5", "^", "2"}], " ", "-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[79]:="],

Cell["The general element of su(n) is", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"suelm", "[", 
   RowBox[{"a_", ",", " ", 
    RowBox[{"n_:", "dim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"k", ",", " ", 
      RowBox[{"c", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"a", "[", "k", "]"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"k", ",", "  ", 
           RowBox[{"n", "^", "2"}]}], "}"}]}], "]"}]}]}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"Declare", "[", 
      RowBox[{"c", ",", "Real"}], "]"}], ";", "\n", "\t\t\t ", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"subasis", "[", "n", "]"}], "[", 
         RowBox[{"[", "k", "]"}], "]"}], "*", 
        RowBox[{"a", "[", "k", "]"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"k", ",", " ", 
         RowBox[{
          RowBox[{"n", "^", "2"}], "-", "1"}]}], "}"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[80]:="],

Cell[BoxData[
 RowBox[{"dim", " ", "=", " ", "5"}]], "Input",
 CellChangeTimes->{{3.471771129002297*^9, 3.471771132351703*^9}},
 CellLabel->"In[82]:="],

Cell[BoxData[
 RowBox[{"abc", " ", "=", " ", 
  RowBox[{"suelm", "[", "a", "]"}]}]], "Input",
 CellLabel->"In[83]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Conjugate", "[", "abc", "]"}], " ", "\[Equal]", " ", 
  RowBox[{"-", " ", 
   RowBox[{"Transpose", "[", "abc", "]"}]}]}]], "Input",
 CellLabel->"In[84]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"suelm", "[", "a", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[85]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"matrixorthonorm", "[", 
   RowBox[{
    RowBox[{"subasis", "[", "]"}], ",", " ", 
    RowBox[{"innerprod", " ", "\[Rule]", " ", "ukilling"}]}], "]"}], 
  "]"}]], "Input",
 CellLabel->"In[86]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[87]:="],

Cell["\<\
Time needed for this orthonormalization: 48 min. New time: 229 s.\
\>", "Text",
 CellChangeTimes->{{3.471771441719528*^9, 3.471771459065112*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"su5list", " ", "=", " ", 
   RowBox[{"%%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[88]:="],

Cell[BoxData[
 RowBox[{"Length", "[", "su5list", "]"}]], "Input",
 CellLabel->"In[89]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"ukilling", "[", 
    RowBox[{
     RowBox[{"su5list", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
     RowBox[{"su5list", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "24"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "24"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[90]:="]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
 CellTags->"ref"],

Cell["\<\
[1] S. HELGASON: Differential Geometry, Lie Groups, and Symmetric Spaces, \
ACADEMIC PRESS, 1978.
[2] R. SULANKE: Spheres in \
http://mathsource.com/Content/Enhancements/Geometry/0210-092.
[3] J. TITS: Tabellen zu den einfachen Lie Gruppen und ihren Darstellungen, \
L.N. in Math. Nr. 40, Springer-Verlag 1967
[4] PEKKA JANHUNEN: Declare.m,  in \
http://www.mathsource.com/Content22/Enhancements/Algebraic/0202-149.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Address", "Subsubtitle"],

Cell["\<\
sulanke@mathematik.hu-berlin.de
Homepage:
http://www-irm.mathematik.hu-berlin.de/~sulanke/\
\>", "Text",
 CellTags->"home"],

Cell["\<\
For comments, hints,  and corrections the author will be very thankful.\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{739, 700},
WindowMargins->{{82, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "rolf", 
   "mymath", "lie"}, "liealgeb.nb.ps", CharacterEncoding -> "ISO8859-1"]},
ShowSelection->True,
SpellingDictionaries->{"CorrectWords"->{
 "Erhard", "orthonormalization", "semisimple", "Activite", "randommatrix", 
  "glkilling", "nullmatrix", "basematrix", "zelm", "gl", "euvec", "outzero", 
  "matrixoutzero", "pseuvec", "matrixorthonorm", "orthonorm", "innerprod", 
  "sl", "pos", "neg", "psoindex", "psokilling", "Pekka", "Janhunen.", 
  "cobasis", "liealg", "liealgun", "Janhunen"}},
FrontEndVersion->"7.0 for Linux x86 (32-bit) (November 10, 2008)",
StyleDefinitions->"TutorialBook.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "ref"->{
  Cell[146390, 4988, 48, 1, 35, "Subtitle",
   CellTags->"ref"]},
 "home"->{
  Cell[146938, 5006, 133, 5, 95, "Text",
   CellTags->"home"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"ref", 148251, 5045},
 {"home", 148328, 5048}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 53, 1, 63, "Title"],
Cell[623, 25, 224, 8, 33, "Subsubtitle",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[872, 37, 202, 5, 35, "Subtitle",
 Evaluatable->False],
Cell[1077, 44, 216, 7, 53, "Subsubtitle",
 Evaluatable->False],
Cell[1296, 53, 54, 1, 33, "Subsubtitle"],
Cell[1353, 56, 1779, 33, 519, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[3157, 93, 34, 0, 38, "Subsubsection"],
Cell[3194, 95, 385, 6, 93, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3616, 106, 49, 0, 93, "Section"],
Cell[CellGroupData[{
Cell[3690, 110, 43, 0, 40, "Subsection"],
Cell[3736, 112, 197, 6, 49, "Text"],
Cell[3936, 120, 92, 3, 27, "Text"],
Cell[4031, 125, 21, 0, 27, "Text"],
Cell[4055, 127, 101, 3, 27, "Text"],
Cell[4159, 132, 1875, 40, 291, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[6071, 177, 40, 0, 34, "Subsection"],
Cell[6114, 179, 134, 2, 27, "Text"],
Cell[6251, 183, 928, 15, 159, "Text"],
Cell[7182, 200, 195, 5, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7414, 210, 101, 1, 40, "Subsection"],
Cell[7518, 213, 1573, 36, 259, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[9128, 254, 78, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[9231, 259, 74, 0, 38, "Subsubsection"],
Cell[9308, 261, 341, 11, 29, "Input",
 InitializationCell->True],
Cell[9652, 274, 82, 2, 29, "Input"],
Cell[9737, 278, 78, 2, 29, "Input"],
Cell[9818, 282, 302, 10, 29, "Input",
 InitializationCell->True],
Cell[10123, 294, 79, 2, 29, "Input"],
Cell[10205, 298, 126, 3, 29, "Input"],
Cell[10334, 303, 84, 2, 29, "Input"],
Cell[10421, 307, 641, 18, 53, "Input",
 InitializationCell->True],
Cell[11065, 327, 212, 5, 29, "Input"],
Cell[11280, 334, 122, 3, 29, "Input"],
Cell[11405, 339, 183, 4, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[11625, 348, 34, 0, 32, "Subsubsection"],
Cell[11662, 350, 260, 8, 50, "Text"],
Cell[11925, 360, 882, 29, 114, "Input",
 InitializationCell->True],
Cell[12810, 391, 137, 3, 32, "Input"],
Cell[12950, 396, 301, 9, 49, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13312, 412, 68, 0, 93, "Section"],
Cell[CellGroupData[{
Cell[13405, 416, 43, 0, 40, "Subsection"],
Cell[13451, 418, 683, 14, 137, "Text"],
Cell[CellGroupData[{
Cell[14159, 436, 57, 0, 38, "Subsubsection"],
Cell[14219, 438, 871, 23, 87, "Input",
 InitializationCell->True],
Cell[15093, 463, 115, 3, 32, "Input"],
Cell[15211, 468, 144, 4, 28, "Input"],
Cell[15358, 474, 178, 3, 45, "Text"],
Cell[15539, 479, 521, 16, 60, "Input",
 InitializationCell->True],
Cell[16063, 497, 116, 3, 32, "Input"],
Cell[16182, 502, 146, 3, 49, "Text"],
Cell[16331, 507, 386, 10, 32, "Input",
 InitializationCell->True],
Cell[16720, 519, 134, 5, 27, "Text"],
Cell[16857, 526, 1015, 27, 168, "Input"],
Cell[17875, 555, 124, 4, 27, "Text"],
Cell[18002, 561, 957, 26, 141, "Input"],
Cell[18962, 589, 68, 0, 27, "Text"],
Cell[19033, 591, 923, 25, 87, "Input"],
Cell[19959, 618, 86, 2, 32, "Input"],
Cell[20048, 622, 291, 9, 32, "Input"],
Cell[20342, 633, 86, 2, 32, "Input"],
Cell[20431, 637, 217, 6, 32, "Input"],
Cell[20651, 645, 86, 2, 32, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[20774, 652, 42, 0, 38, "Subsubsection"],
Cell[20819, 654, 182, 4, 29, "Input"],
Cell[21004, 660, 225, 6, 25, "Input"],
Cell[21232, 668, 274, 7, 25, "Input"],
Cell[21509, 677, 274, 7, 25, "Input"],
Cell[21786, 686, 218, 6, 51, "Text"],
Cell[22007, 694, 197, 6, 29, "Input"],
Cell[22207, 702, 159, 4, 25, "Input"],
Cell[22369, 708, 86, 2, 25, "Input"],
Cell[22458, 712, 86, 2, 25, "Input"],
Cell[22547, 716, 87, 2, 25, "Input"],
Cell[22637, 720, 87, 2, 25, "Input"],
Cell[22727, 724, 85, 2, 25, "Input"],
Cell[22815, 728, 86, 2, 25, "Input"],
Cell[22904, 732, 89, 2, 25, "Input"],
Cell[22996, 736, 90, 2, 25, "Input"],
Cell[23089, 740, 281, 9, 25, "Input"],
Cell[23373, 751, 250, 7, 25, "Input"],
Cell[23626, 760, 154, 4, 25, "Input"],
Cell[23783, 766, 461, 13, 72, "Input"],
Cell[24247, 781, 287, 8, 25, "Input"],
Cell[24537, 791, 122, 3, 20, "Text"],
Cell[24662, 796, 244, 6, 29, "Input"],
Cell[24909, 804, 34, 0, 20, "Text"],
Cell[24946, 806, 250, 7, 29, "Input"],
Cell[25199, 815, 259, 6, 25, "Input"],
Cell[25461, 823, 249, 6, 25, "Input"],
Cell[25713, 831, 130, 3, 25, "Input"],
Cell[25846, 836, 122, 3, 25, "Input"],
Cell[25971, 841, 122, 3, 25, "Input"],
Cell[26096, 846, 118, 3, 25, "Input"],
Cell[26217, 851, 118, 3, 29, "Input"],
Cell[26338, 856, 117, 3, 29, "Input"],
Cell[26458, 861, 152, 4, 25, "Input"],
Cell[26613, 867, 152, 4, 25, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[26802, 876, 145, 2, 32, "Subsubsection"],
Cell[26950, 880, 347, 8, 43, "Text"],
Cell[27300, 890, 1199, 34, 122, "Input",
 InitializationCell->True],
Cell[28502, 926, 35, 0, 24, "Text"],
Cell[28540, 928, 588, 18, 53, "Input",
 InitializationCell->True],
Cell[29131, 948, 172, 4, 29, "Input"],
Cell[29306, 954, 179, 4, 25, "Input"],
Cell[29488, 960, 201, 4, 20, "Text"],
Cell[29692, 966, 1729, 46, 122, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[31458, 1017, 40, 0, 35, "Subsubsection"],
Cell[31501, 1019, 145, 4, 29, "Input"],
Cell[31649, 1025, 214, 6, 29, "Input"],
Cell[31866, 1033, 231, 6, 29, "Input"],
Cell[32100, 1041, 188, 4, 29, "Input"],
Cell[32291, 1047, 199, 6, 29, "Input"],
Cell[32493, 1055, 199, 6, 29, "Input"],
Cell[32695, 1063, 265, 7, 29, "Input"],
Cell[32963, 1072, 199, 6, 29, "Input"],
Cell[33165, 1080, 199, 6, 29, "Input"],
Cell[33367, 1088, 99, 2, 24, "Text"],
Cell[33469, 1092, 199, 6, 29, "Input"],
Cell[33671, 1100, 199, 6, 29, "Input"],
Cell[33873, 1108, 269, 6, 29, "Input"],
Cell[34145, 1116, 169, 5, 29, "Input"],
Cell[34317, 1123, 178, 5, 29, "Input"],
Cell[34498, 1130, 220, 6, 29, "Input"],
Cell[34721, 1138, 119, 3, 29, "Input"],
Cell[34843, 1143, 453, 13, 29, "Input"],
Cell[35299, 1158, 199, 6, 29, "Input"],
Cell[35501, 1166, 86, 2, 29, "Input"],
Cell[35590, 1170, 199, 6, 29, "Input"],
Cell[35792, 1178, 637, 18, 53, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[36466, 1201, 140, 2, 35, "Subsubsection"],
Cell[36609, 1205, 85, 2, 24, "Text"],
Cell[36697, 1209, 549, 15, 76, "Input",
 InitializationCell->True],
Cell[37249, 1226, 378, 12, 53, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[37664, 1243, 75, 0, 35, "Subsubsection"],
Cell[37742, 1245, 106, 3, 24, "Text"],
Cell[37851, 1250, 202, 6, 29, "Input"],
Cell[38056, 1258, 183, 5, 24, "Text"],
Cell[38242, 1265, 322, 7, 43, "Text"],
Cell[38567, 1274, 938, 26, 122, "Input",
 InitializationCell->True],
Cell[39508, 1302, 237, 7, 29, "Input"],
Cell[39748, 1311, 303, 8, 29, "Input"],
Cell[40054, 1321, 446, 13, 53, "Input"],
Cell[40503, 1336, 446, 13, 53, "Input"],
Cell[40952, 1351, 446, 13, 53, "Input"],
Cell[41401, 1366, 446, 13, 53, "Input"],
Cell[41850, 1381, 102, 2, 24, "Text"],
Cell[41955, 1385, 177, 5, 29, "Input"],
Cell[42135, 1392, 85, 2, 29, "Input"],
Cell[42223, 1396, 220, 6, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[42480, 1407, 51, 0, 35, "Subsubsection"],
Cell[42534, 1409, 238, 4, 43, "Text"],
Cell[42775, 1415, 741, 21, 99, "Input"],
Cell[43519, 1438, 256, 6, 29, "Input"],
Cell[43778, 1446, 269, 5, 29, "Input"],
Cell[44050, 1453, 109, 3, 24, "Text"],
Cell[44162, 1458, 261, 8, 29, "Input",
 InitializationCell->True],
Cell[44426, 1468, 114, 3, 29, "Input"],
Cell[44543, 1473, 146, 3, 43, "Text"],
Cell[44692, 1478, 604, 18, 76, "Input"],
Cell[45299, 1498, 270, 8, 29, "Input"],
Cell[45572, 1508, 54, 0, 24, "Text"],
Cell[45629, 1510, 173, 5, 29, "Input"],
Cell[45805, 1517, 180, 5, 29, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[46034, 1528, 44, 0, 38, "Subsection"],
Cell[46081, 1530, 607, 10, 131, "Text"],
Cell[46691, 1542, 1587, 43, 145, "Input",
 InitializationCell->True],
Cell[48281, 1587, 90, 2, 24, "Text"],
Cell[48374, 1591, 935, 29, 99, "Input",
 InitializationCell->True],
Cell[49312, 1622, 160, 3, 43, "Text"],
Cell[49475, 1627, 466, 13, 76, "Input",
 InitializationCell->True],
Cell[49944, 1642, 11407, 293, 1433, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[61376, 1939, 30, 0, 35, "Subsubsection"],
Cell[61409, 1941, 151, 4, 29, "Input"],
Cell[61563, 1947, 109, 3, 29, "Input"],
Cell[61675, 1952, 147, 4, 29, "Input"],
Cell[61825, 1958, 173, 5, 29, "Input"],
Cell[62001, 1965, 109, 3, 29, "Input"],
Cell[62113, 1970, 173, 5, 29, "Input"],
Cell[62289, 1977, 109, 3, 29, "Input"],
Cell[62401, 1982, 277, 8, 29, "Input"],
Cell[62681, 1992, 171, 4, 29, "Input"],
Cell[62855, 1998, 467, 15, 53, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[63371, 2019, 96, 2, 38, "Subsection"],
Cell[63470, 2023, 127, 3, 24, "Text"],
Cell[63600, 2028, 311, 9, 29, "Input",
 InitializationCell->True],
Cell[63914, 2039, 531, 20, 54, "Input"],
Cell[64448, 2061, 117, 1, 24, "Text"],
Cell[64568, 2064, 540, 17, 53, "Input"],
Cell[65111, 2083, 102, 1, 24, "Text"],
Cell[65216, 2086, 222, 6, 29, "Input"],
Cell[65441, 2094, 105, 3, 29, "Input"],
Cell[65549, 2099, 298, 9, 29, "Input"],
Cell[65850, 2110, 565, 18, 53, "Input"],
Cell[66418, 2130, 162, 3, 43, "Text"],
Cell[66583, 2135, 194, 4, 29, "Input"],
Cell[66780, 2141, 648, 21, 76, "Input"],
Cell[67431, 2164, 173, 3, 43, "Text"],
Cell[67607, 2169, 155, 4, 29, "Input"],
Cell[67765, 2175, 367, 10, 43, "Text"],
Cell[68135, 2187, 101, 3, 29, "Input"],
Cell[68239, 2192, 157, 5, 29, "Input"],
Cell[68399, 2199, 256, 8, 29, "Input"],
Cell[68658, 2209, 405, 13, 53, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[69100, 2227, 156, 2, 38, "Subsection"],
Cell[69259, 2231, 159, 3, 43, "Text"],
Cell[69421, 2236, 121, 3, 24, "Text"],
Cell[69545, 2241, 471, 8, 81, "Text"],
Cell[CellGroupData[{
Cell[70041, 2253, 43, 0, 35, "Subsubsection"],
Cell[70087, 2255, 886, 26, 122, "Input",
 InitializationCell->True],
Cell[70976, 2283, 835, 25, 76, "Input",
 InitializationCell->True],
Cell[71814, 2310, 897, 27, 99, "Input"],
Cell[72714, 2339, 84, 2, 29, "Input"],
Cell[72801, 2343, 85, 2, 29, "Input"],
Cell[72889, 2347, 169, 4, 29, "Input"],
Cell[73061, 2353, 217, 4, 29, "Input"],
Cell[73281, 2359, 166, 4, 29, "Input"],
Cell[73450, 2365, 175, 4, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[73662, 2374, 56, 0, 35, "Subsubsection"],
Cell[73721, 2376, 232, 6, 29, "Input"],
Cell[73956, 2384, 417, 14, 29, "Input"],
Cell[74376, 2400, 232, 6, 29, "Input"],
Cell[74611, 2408, 148, 4, 29, "Input"],
Cell[74762, 2414, 88, 2, 29, "Input"],
Cell[74853, 2418, 465, 14, 53, "Input"],
Cell[75321, 2434, 415, 10, 29, "Input"],
Cell[75739, 2446, 101, 3, 29, "Input"],
Cell[75843, 2451, 473, 11, 43, "Text"],
Cell[76319, 2464, 161, 5, 29, "Input"],
Cell[76483, 2471, 88, 2, 29, "Input"],
Cell[76574, 2475, 449, 15, 53, "Input"],
Cell[77026, 2492, 260, 6, 43, "Text"],
Cell[77289, 2500, 64, 1, 24, "Text"],
Cell[77356, 2503, 161, 3, 43, "Text"],
Cell[77520, 2508, 137, 2, 24, "Text"],
Cell[77660, 2512, 165, 4, 55, "Text"],
Cell[77828, 2518, 373, 11, 53, "Input"],
Cell[78204, 2531, 117, 3, 29, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[78382, 2541, 54, 0, 61, "Section"],
Cell[CellGroupData[{
Cell[78461, 2545, 98, 1, 38, "Subsection"],
Cell[78562, 2548, 146, 3, 43, "Text"],
Cell[78711, 2553, 465, 13, 53, "Input",
 InitializationCell->True],
Cell[79179, 2568, 119, 2, 29, "Input"],
Cell[79301, 2572, 104, 3, 29, "Input"],
Cell[79408, 2577, 137, 4, 29, "Input"],
Cell[79548, 2583, 104, 3, 29, "Input"],
Cell[79655, 2588, 73, 0, 24, "Text"],
Cell[79731, 2590, 104, 3, 29, "Input"],
Cell[79838, 2595, 38, 0, 24, "Text"],
Cell[79879, 2597, 572, 19, 53, "Input",
 InitializationCell->True],
Cell[80454, 2618, 212, 5, 29, "Input"],
Cell[80669, 2625, 74, 0, 24, "Text"],
Cell[80746, 2627, 759, 24, 53, "Input",
 InitializationCell->True],
Cell[81508, 2653, 114, 3, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[81659, 2661, 93, 1, 38, "Subsection"],
Cell[81755, 2664, 33, 0, 24, "Text"],
Cell[81791, 2666, 975, 27, 145, "Input",
 InitializationCell->True],
Cell[82769, 2695, 109, 3, 24, "Text"],
Cell[82881, 2700, 237, 7, 29, "Input"],
Cell[83121, 2709, 121, 3, 24, "Text"],
Cell[83245, 2714, 238, 7, 29, "Input"],
Cell[83486, 2723, 151, 3, 29, "Input"],
Cell[83640, 2728, 374, 11, 29, "Input"],
Cell[84017, 2741, 66, 0, 24, "Text"],
Cell[84086, 2743, 237, 7, 29, "Input"],
Cell[84326, 2752, 119, 3, 24, "Text"],
Cell[84448, 2757, 172, 5, 29, "Input"],
Cell[84623, 2764, 64, 0, 24, "Text"],
Cell[84690, 2766, 78, 2, 29, "Input"],
Cell[84771, 2770, 319, 10, 29, "Input"],
Cell[85093, 2782, 101, 3, 29, "Input"],
Cell[85197, 2787, 255, 8, 29, "Input"],
Cell[85455, 2797, 456, 15, 53, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[85960, 2818, 144, 3, 61, "Section"],
Cell[CellGroupData[{
Cell[86129, 2825, 50, 0, 38, "Subsection"],
Cell[86182, 2827, 520, 8, 100, "Text"],
Cell[86705, 2837, 886, 26, 122, "Input",
 InitializationCell->True],
Cell[87594, 2865, 640, 21, 76, "Input",
 InitializationCell->True],
Cell[88237, 2888, 92, 2, 24, "Text"],
Cell[88332, 2892, 860, 26, 53, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[89217, 2922, 40, 0, 35, "Subsubsection"],
Cell[89260, 2924, 119, 2, 29, "Input"],
Cell[89382, 2928, 119, 2, 29, "Input"],
Cell[89504, 2932, 108, 3, 29, "Input"],
Cell[89615, 2937, 80, 2, 29, "Input"],
Cell[89698, 2941, 112, 3, 29, "Input"],
Cell[89813, 2946, 125, 6, 52, "Input"],
Cell[89941, 2954, 125, 6, 52, "Input"],
Cell[90069, 2962, 129, 6, 52, "Input"],
Cell[90201, 2970, 116, 3, 29, "Input"],
Cell[90320, 2975, 121, 3, 29, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[90490, 2984, 52, 0, 38, "Subsection"],
Cell[90545, 2986, 1025, 28, 145, "Input",
 InitializationCell->True],
Cell[91573, 3016, 110, 3, 24, "Text"],
Cell[91686, 3021, 370, 12, 29, "Input",
 InitializationCell->True],
Cell[92059, 3035, 127, 3, 24, "Text"],
Cell[92189, 3040, 109, 3, 29, "Input"],
Cell[92301, 3045, 179, 5, 29, "Input"],
Cell[92483, 3052, 105, 3, 24, "Text"],
Cell[92591, 3057, 308, 8, 29, "Input"],
Cell[92902, 3067, 109, 3, 29, "Input"],
Cell[93014, 3072, 272, 8, 29, "Input"],
Cell[93289, 3082, 176, 3, 43, "Text"],
Cell[CellGroupData[{
Cell[93490, 3089, 136, 3, 35, "Subsubsection"],
Cell[93629, 3094, 215, 6, 29, "Input"],
Cell[93847, 3102, 313, 9, 29, "Input"],
Cell[94163, 3113, 168, 4, 29, "Input"],
Cell[94334, 3119, 180, 5, 29, "Input"],
Cell[94517, 3126, 252, 7, 87, "Text"],
Cell[94772, 3135, 236, 8, 29, "Input"],
Cell[95011, 3145, 485, 10, 93, "Text"],
Cell[95499, 3157, 145, 3, 43, "Text"],
Cell[95647, 3162, 234, 7, 29, "Input"],
Cell[95884, 3171, 113, 3, 29, "Input"],
Cell[96000, 3176, 262, 7, 53, "Input"],
Cell[96265, 3185, 117, 1, 24, "Text"],
Cell[96385, 3188, 277, 8, 29, "Input"],
Cell[96665, 3198, 293, 9, 29, "Input"],
Cell[96961, 3209, 523, 15, 76, "Input"],
Cell[97487, 3226, 309, 7, 43, "Text"],
Cell[97799, 3235, 168, 4, 29, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[98028, 3246, 58, 0, 61, "Section"],
Cell[98089, 3248, 243, 4, 43, "Text"],
Cell[CellGroupData[{
Cell[98357, 3256, 90, 1, 38, "Subsection"],
Cell[98450, 3259, 323, 6, 62, "Text"],
Cell[98776, 3267, 1171, 37, 99, "Input",
 InitializationCell->True],
Cell[99950, 3306, 115, 3, 29, "Input"],
Cell[100068, 3311, 81, 2, 29, "Input"],
Cell[100152, 3315, 47, 0, 24, "Text"],
Cell[100202, 3317, 573, 18, 76, "Input",
 InitializationCell->True],
Cell[100778, 3337, 95, 2, 24, "Text"],
Cell[100876, 3341, 225, 7, 29, "Input"],
Cell[101104, 3350, 225, 7, 29, "Input"],
Cell[101332, 3359, 225, 7, 29, "Input"],
Cell[101560, 3368, 442, 14, 29, "Input"],
Cell[102005, 3384, 225, 7, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[102267, 3396, 51, 0, 38, "Subsection"],
Cell[102321, 3398, 199, 4, 43, "Text"],
Cell[102523, 3404, 2562, 76, 214, "Input",
 InitializationCell->True],
Cell[105088, 3482, 85, 2, 24, "Text"],
Cell[105176, 3486, 545, 17, 76, "Input",
 InitializationCell->True],
Cell[105724, 3505, 129, 3, 24, "Text"],
Cell[105856, 3510, 516, 17, 53, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[106397, 3531, 40, 0, 35, "Subsubsection"],
Cell[106440, 3533, 152, 4, 29, "Input"],
Cell[106595, 3539, 284, 9, 29, "Input"],
Cell[106882, 3550, 216, 5, 29, "Input"],
Cell[107101, 3557, 118, 3, 29, "Input"],
Cell[107222, 3562, 320, 10, 29, "Input"],
Cell[107545, 3574, 216, 5, 29, "Input"],
Cell[107764, 3581, 76, 0, 24, "Text"],
Cell[107843, 3583, 140, 4, 29, "Input"],
Cell[107986, 3589, 206, 5, 29, "Input"],
Cell[108195, 3596, 59, 0, 24, "Text"],
Cell[108257, 3598, 229, 7, 29, "Input"],
Cell[108489, 3607, 106, 3, 29, "Input"],
Cell[108598, 3612, 84, 2, 29, "Input"],
Cell[108685, 3616, 124, 3, 29, "Input"],
Cell[108812, 3621, 88, 2, 29, "Input"],
Cell[108903, 3625, 49, 0, 24, "Text"],
Cell[108955, 3627, 140, 4, 29, "Input"],
Cell[109098, 3633, 224, 7, 29, "Input"],
Cell[109325, 3642, 99, 2, 24, "Text"],
Cell[109427, 3646, 244, 8, 29, "Input"],
Cell[109674, 3656, 83, 2, 29, "Input"],
Cell[109760, 3660, 83, 2, 29, "Input"],
Cell[109846, 3664, 84, 2, 29, "Input"],
Cell[109933, 3668, 66, 0, 24, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[110048, 3674, 51, 0, 38, "Subsection"],
Cell[110102, 3676, 100, 2, 24, "Text"],
Cell[110205, 3680, 934, 26, 122, "Input",
 InitializationCell->True],
Cell[111142, 3708, 352, 9, 29, "Input"],
Cell[111497, 3719, 75, 0, 24, "Text"],
Cell[111575, 3721, 246, 7, 29, "Input"],
Cell[111824, 3730, 352, 9, 29, "Input"],
Cell[112179, 3741, 351, 9, 29, "Input"],
Cell[112533, 3752, 175, 4, 29, "Input"],
Cell[112711, 3758, 134, 3, 24, "Text"],
Cell[112848, 3763, 83, 2, 29, "Input"],
Cell[112934, 3767, 84, 2, 29, "Input"],
Cell[113021, 3771, 289, 9, 29, "Input"],
Cell[113313, 3782, 102, 3, 29, "Input"],
Cell[113418, 3787, 96, 4, 24, "Text"],
Cell[113517, 3793, 139, 4, 29, "Input"],
Cell[113659, 3799, 299, 9, 29, "Input",
 InitializationCell->True],
Cell[113961, 3810, 236, 6, 29, "Input"],
Cell[114200, 3818, 419, 14, 29, "Input"],
Cell[114622, 3834, 236, 6, 29, "Input"],
Cell[114861, 3842, 131, 4, 29, "Input"],
Cell[114995, 3848, 117, 3, 29, "Input"],
Cell[115115, 3853, 544, 18, 53, "Input"],
Cell[115662, 3873, 270, 6, 43, "Text"],
Cell[115935, 3881, 274, 7, 29, "Input"],
Cell[116212, 3890, 102, 3, 29, "Input"],
Cell[116317, 3895, 186, 6, 29, "Input"],
Cell[116506, 3903, 117, 3, 29, "Input"],
Cell[116626, 3908, 282, 9, 29, "Input"],
Cell[116911, 3919, 544, 18, 53, "Input"],
Cell[117458, 3939, 130, 3, 24, "Text"],
Cell[117591, 3944, 195, 6, 29, "Input"],
Cell[117789, 3952, 52, 0, 24, "Text"],
Cell[117844, 3954, 371, 12, 29, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[118264, 3972, 89, 2, 86, "Section"],
Cell[118356, 3976, 398, 9, 71, "Text"],
Cell[CellGroupData[{
Cell[118779, 3989, 41, 0, 40, "Subsection"],
Cell[118823, 3991, 423, 13, 32, "Input",
 InitializationCell->True],
Cell[119249, 4006, 592, 18, 87, "Input",
 InitializationCell->True],
Cell[119844, 4026, 369, 12, 32, "Input",
 InitializationCell->True],
Cell[120216, 4040, 1232, 36, 168, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[121473, 4080, 30, 0, 38, "Subsubsection"],
Cell[121506, 4082, 159, 6, 27, "Text"],
Cell[121668, 4090, 118, 3, 32, "Input"],
Cell[121789, 4095, 84, 2, 32, "Input"],
Cell[121876, 4099, 179, 4, 32, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[122104, 4109, 51, 0, 40, "Subsection"],
Cell[122158, 4111, 190, 4, 49, "Text"],
Cell[122351, 4117, 245, 7, 32, "Input"],
Cell[122599, 4126, 107, 3, 27, "Text"],
Cell[122709, 4131, 319, 10, 32, "Input"],
Cell[123031, 4143, 346, 11, 32, "Input"],
Cell[123380, 4156, 84, 2, 32, "Input"],
Cell[123467, 4160, 458, 11, 71, "Text"],
Cell[123928, 4173, 223, 4, 32, "Input"],
Cell[124154, 4179, 69, 1, 27, "Text"],
Cell[124226, 4182, 77, 2, 32, "Input"],
Cell[124306, 4186, 61, 0, 27, "Text"],
Cell[124370, 4188, 94, 2, 32, "Input"],
Cell[124467, 4192, 282, 9, 32, "Input"],
Cell[124752, 4203, 149, 4, 32, "Input"],
Cell[124904, 4209, 216, 7, 32, "Input"],
Cell[125123, 4218, 92, 2, 32, "Input"],
Cell[125218, 4222, 86, 2, 27, "Text"],
Cell[125307, 4226, 74, 2, 32, "Input"],
Cell[125384, 4230, 143, 3, 32, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[125564, 4238, 76, 0, 40, "Subsection"],
Cell[CellGroupData[{
Cell[125665, 4242, 36, 0, 38, "Subsubsection"],
Cell[125704, 4244, 290, 8, 61, "Text"],
Cell[125997, 4254, 168, 4, 32, "Input"],
Cell[126168, 4260, 941, 29, 87, "Input"],
Cell[127112, 4291, 502, 17, 60, "Input"],
Cell[127617, 4310, 502, 17, 60, "Input"],
Cell[128122, 4329, 438, 15, 60, "Input"],
Cell[128563, 4346, 1384, 40, 168, "Input"],
Cell[129950, 4388, 755, 23, 87, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[130742, 4416, 40, 0, 38, "Subsubsection"],
Cell[130785, 4418, 139, 4, 32, "Input"],
Cell[130927, 4424, 323, 10, 32, "Input"],
Cell[131253, 4436, 111, 3, 32, "Input"],
Cell[131367, 4441, 139, 4, 32, "Input"],
Cell[131509, 4447, 139, 4, 32, "Input"],
Cell[131651, 4453, 177, 5, 32, "Input"],
Cell[131831, 4460, 321, 10, 32, "Input"],
Cell[132155, 4472, 169, 5, 32, "Input"],
Cell[132327, 4479, 292, 8, 32, "Input"],
Cell[132622, 4489, 226, 7, 32, "Input"],
Cell[132851, 4498, 172, 5, 32, "Input"],
Cell[133026, 4505, 194, 6, 32, "Input"],
Cell[133223, 4513, 233, 7, 32, "Input"],
Cell[133459, 4522, 86, 2, 32, "Input"],
Cell[133548, 4526, 273, 8, 32, "Input"],
Cell[133824, 4536, 274, 8, 32, "Input"],
Cell[134101, 4546, 182, 4, 32, "Input"],
Cell[134286, 4552, 151, 3, 49, "Text"],
Cell[134440, 4557, 217, 6, 32, "Input"],
Cell[134660, 4565, 462, 15, 60, "Input"],
Cell[135125, 4582, 84, 2, 32, "Input"],
Cell[135212, 4586, 228, 6, 32, "Input"],
Cell[135443, 4594, 182, 5, 27, "Text"],
Cell[135628, 4601, 160, 5, 32, "Input"],
Cell[135791, 4608, 88, 2, 32, "Input"],
Cell[135882, 4612, 440, 14, 32, "Input"],
Cell[136325, 4628, 230, 6, 27, "Text"],
Cell[136558, 4636, 173, 5, 32, "Input"],
Cell[136734, 4643, 141, 3, 32, "Input"],
Cell[136878, 4648, 608, 19, 87, "Input"],
Cell[137489, 4669, 168, 4, 32, "Input"],
Cell[137660, 4675, 227, 6, 27, "Text"],
Cell[137890, 4683, 212, 6, 32, "Input"],
Cell[138105, 4691, 246, 7, 32, "Input"],
Cell[138354, 4700, 232, 6, 27, "Text"],
Cell[138589, 4708, 143, 4, 32, "Input"],
Cell[138735, 4714, 161, 5, 32, "Input"],
Cell[138899, 4721, 88, 2, 32, "Input"],
Cell[138990, 4725, 464, 14, 60, "Input"],
Cell[139457, 4741, 115, 1, 27, "Text"],
Cell[139575, 4744, 238, 6, 32, "Input"],
Cell[139816, 4752, 151, 3, 32, "Input"],
Cell[139970, 4757, 243, 7, 32, "Input"],
Cell[140216, 4766, 130, 1, 27, "Text"],
Cell[140349, 4769, 167, 4, 32, "Input"],
Cell[140519, 4775, 161, 5, 32, "Input"],
Cell[140683, 4782, 417, 13, 60, "Input"],
Cell[141103, 4797, 281, 9, 32, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[141433, 4812, 64, 0, 40, "Subsection"],
Cell[141500, 4814, 266, 5, 71, "Text"],
Cell[141769, 4821, 150, 3, 32, "Input"],
Cell[141922, 4826, 1131, 36, 114, "Input"],
Cell[143056, 4864, 469, 15, 60, "Input"],
Cell[143528, 4881, 47, 0, 27, "Text"],
Cell[143578, 4883, 988, 31, 87, "Input"],
Cell[144569, 4916, 151, 3, 32, "Input"],
Cell[144723, 4921, 117, 3, 32, "Input"],
Cell[144843, 4926, 190, 5, 32, "Input"],
Cell[145036, 4933, 115, 3, 32, "Input"],
Cell[145154, 4938, 244, 7, 32, "Input"],
Cell[145401, 4947, 101, 3, 32, "Input"],
Cell[145505, 4952, 155, 3, 27, "Text"],
Cell[145663, 4957, 162, 5, 32, "Input"],
Cell[145828, 4964, 89, 2, 32, "Input"],
Cell[145920, 4968, 409, 13, 60, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[146390, 4988, 48, 1, 35, "Subtitle",
 CellTags->"ref"],
Cell[146441, 4991, 439, 9, 195, "Text"],
Cell[CellGroupData[{
Cell[146905, 5004, 30, 0, 33, "Subsubtitle"],
Cell[146938, 5006, 133, 5, 95, "Text",
 CellTags->"home"],
Cell[147074, 5013, 95, 2, 27, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
